_positive = set(
    [
        "Abba",
        "gebėjimas",
        "NO TRANSLATION",
        "absoliutus",
        "atleidimas",
        "sugeria",
        "gausu",
        "akademinis",
        "akademija",
        "priimtinas",
        "priėmimas",
        "prieinama",
        "apdovanojimas",
        "apgyvendinimas",
        "asortimentas",
        "įvykdyti",
        "įvykdytas",
        "pasiekimas",
        "susitarti",
        "atskaitomybė",
        "atskaitingas",
        "akredituotas",
        "NO TRANSLATION",
        "tiksliai",
        "ace",
        "pasiekti",
        "pasiekimas",
        "patvirtinimas",
        "įsigyti",
        "įsigijimas",
        "akrobatas",
        "veiksmas",
        "faktinis",
        "aštrumas",
        "sumanumas",
        "prisitaikyti",
        "pritaikomas",
        "adresai",
        "adept",
        "NO TRANSLATION",
        "adjunct",
        "žavisi",
        "admirolas",
        "susižavėjimas",
        "grožėtis",
        "gerbėjas",
        "priimtinas",
        "žavinga",
        "adoracija",
        "garbinti",
        "iš anksto",
        "pažengusi",
        "pažanga",
        "pranašumas",
        "naudinga",
        "Adventas",
        "nuotykis",
        "nuotykis",
        "patartinas",
        "patarti",
        "patarėjas",
        "advokatas",
        "estetinis",
        "estetika",
        "draugiškas",
        "meilė",
        "susijusi",
        "patvirtinti",
        "patvirtinimas",
        "teigiamas",
        "teigiamai",
        "gerovę",
        "turtingas",
        "sau leisti",
        "NO TRANSLATION",
        "judrus",
        "judrumas",
        "sutinku",
        "malonus",
        "susitarta",
        "susitarti",
        "susitarimas",
        "Žemdirbystė",
        "priekyje",
        "pagalba",
        "pagalbą",
        "alabastras",
        "budrumas",
        "NO TRANSLATION",
        "gyvas",
        "atsipalaiduoti",
        "ištikimybė",
        "allegoras",
        "palengvinti",
        "palengvinimas",
        "sąjungininkas",
        "leidžiama",
        "Allure",
        "viliojantis",
        "sąjungininkas",
        "visagalis",
        "aloha",
        "nuostabiai",
        "ambasadorius",
        "ambicija",
        "pagerinti",
        "amen",
        "paklusnumas",
        "pataisyti",
        "taiso",
        "malonumas",
        "linksmas",
        "draugiškas",
        "amnestija",
        "NO TRANSLATION",
        "linksmintis",
        "linksma",
        "pramogos",
        "juokinga",
        "analitikas",
        "inkaras",
        "tvirtinimas",
        "angelas",
        "angeliškas",
        "gyvinti",
        "animacinis",
        "antibiotikai",
        "priešnuodis",
        "priešgrybeliniai",
        "Senovinis",
        "antiseptikas",
        "aplomb",
        "Apologetic",
        "Atsiprašau",
        "Atsiprašau",
        "apaštalas",
        "plojimai",
        "dėkingi",
        "aprobavimas",
        "patvirtinimas",
        "patvirtinti",
        "tvirtinimas",
        "apt",
        "tinkamumas",
        "archeologija",
        "karštas",
        "bjaurus",
        "aristokratija",
        "aristokratiškas",
        "šarvai",
        "aromatas",
        "pakelti",
        "masyvas",
        "menas",
        "suformuluoti",
        "sąveika",
        "amatininkas",
        "NO TRANSLATION",
        "meninis",
        "ascendancy",
        "pakilimas",
        "aspiracija",
        "aspira",
        "siekiantis",
        "surinkimas",
        "pritarimas",
        "teigdamas",
        "turtas",
        "padėti",
        "parama",
        "bendradarbis",
        "palengvinti",
        "garantija",
        "patikėta",
        "NO TRANSLATION",
        "nuostaba",
        "astrologas",
        "astronautas",
        "astronomas",
        "akli",
        "sportininkas",
        "Atletiškas",
        "atomas",
        "Atonas",
        "atpirkimas",
        "priesaga",
        "pasiekiamas",
        "pasiekimai",
        "palydovas",
        "dėmesio",
        "dėmesingas",
        "patvirtinti",
        "advokatas",
        "pritraukimas",
        "patrauklumas",
        "didinti",
        "Rugpjūtis",
        "teta",
        "aura",
        "palankus",
        "autentiškas",
        "autentiškumas",
        "autorius",
        "autoritetingas",
        "institucija",
        "leidimas",
        "įgaliotas",
        "avataras",
        "apdovanojimas",
        "ay",
        "aye",
        "kūdikis",
        "bakalaureatas",
        "pagrindas",
        "balansas",
        "subalansuotas",
        "baladė",
        "baletas",
        "balsavimas",
        "balzamas",
        "banketą",
        "krikštas",
        "krikštas",
        "baras",
        "derėtis",
        "krepšinis",
        "bastionas",
        "vonia",
        "spindulys",
        "spinduliuojantis",
        "grožis",
        "grazus",
        "pagražinti",
        "grožis",
        "pagrindas",
        "alus",
        "tinkamas",
        "drauge",
        "tikintis",
        "geradarys",
        "naudingas",
        "nauda",
        "geranoriškumas",
        "gerybingas",
        "krantinė",
        "susituokęs",
        "gerinimas",
        "gėrimas",
        "biblinis",
        "dvikalbis",
        "Gimdymas",
        "gimtadienis",
        "nepriekaištingas",
        "palaiminti",
        "palaimintas",
        "palaiminimas",
        "palaiminimai",
        "palaima",
        "palaimingas",
        "beverčiai",
        "žydi",
        "žiedas",
        "sargybinis",
        "drąsus",
        "drąsa",
        "sustiprinti",
        "bonanza",
        "NO TRANSLATION",
        "premija",
        "bookish",
        "knygynas",
        "palaima",
        "puikus",
        "lazda",
        "puokštė",
        "smegenys",
        "drąsa",
        "pusryčiai",
        "vestuvės",
        "nuotaka",
        "jaunikis",
        "pamergė",
        "ryškesni",
        "ryškumas",
        "puikus",
        "brocade",
        "brolis",
        "brolija",
        "broliai",
        "bičiulis",
        "statyti",
        "pastatas",
        "buldogas",
        "bulletproof",
        "plūdurys",
        "autobusas",
        "butleris",
        "sviestas",
        "buxom",
        "Buzz",
        "Taksi",
        "kabinetas",
        "kavinė",
        "skaičiuotuvas",
        "veršelis",
        "ramus",
        "kanarėlė",
        "atviras",
        "kandidatas",
        "saldainiai",
        "kapitalistinė",
        "kapitonas",
        "patraukti",
        "patraukliai",
        "karjera",
        "atsargiai",
        "atsargiai",
        "glamžyti",
        "prižiūrėtojas",
        "carol",
        "kaskados",
        "pinigai",
        "kategoriškas",
        "patenkinti",
        "katartis",
        "katedra",
        "atsargus",
        "atsargiai",
        "švenčiamas",
        "šventė",
        "šventė",
        "dangus",
        "centras",
        "centurionas",
        "cerebralinis",
        "ceremonija",
        "tikrumas",
        "pirmininkas",
        "pirmininkė",
        "čempionas",
        "skanduoti",
        "įkroviklis",
        "labdaros",
        "labdara",
        "žavesio",
        "žavus",
        "lvalumas",
        "bangavimas",
        "kontrolinis sąrašas",
        "nudžiuginti",
        "linksmas",
        "linksmas",
        "linksmas",
        "NO TRANSLATION",
        "chemikas",
        "puoselėti",
        "vyšnia",
        "vadas",
        "vaikas",
        "vaikystę",
        "chirp",
        "chisel",
        "riteriai",
        "šokoladas",
        "pasirinkimas",
        "choras",
        "choras",
        "choras",
        "pasirinkta",
        "berniukas",
        "kronika",
        "siautėti",
        "bažnyčia",
        "sidras",
        "apipjaustymas",
        "pilietis",
        "civilinis",
        "malonumas",
        "civilizacija",
        "civilizuotas",
        "aiškiaregis",
        "ploti",
        "išsiaiškinti",
        "klasikinis",
        "klasikinis",
        "klasika",
        "klasifikuoti",
        "švarus",
        "valymas",
        "švara",
        "švariai",
        "valyti",
        "valymas",
        "klirensas",
        "aiškumas",
        "klerikas",
        "protingas",
        "protingumas",
        "kulminacija",
        "artimas",
        "uždarymas",
        "NO TRANSLATION",
        "klounas",
        "koalicija",
        "pakrantė",
        "kartu egzistuoja",
        "įtikinamai",
        "pažintinis",
        "nuoseklumas",
        "nuoseklus",
        "darni",
        "kolektyviai",
        "pulkininkas",
        "milžiniškas",
        "komfortas",
        "komendantas",
        "įsakymas",
        "prisiminti",
        "minėjimas",
        "atminimo diena",
        "pagirti",
        "pagirtinas",
        "komentatorius",
        "padaryta",
        "Commodore",
        "sąjunga",
        "bendrauti",
        "komunikacinis",
        "bendrystė",
        "bendruomenė",
        "komutacija",
        "važinėti",
        "kompanionas",
        "užuojauta",
        "sąžiningas",
        "suderinamumas",
        "suderinama",
        "įtikinantis",
        "kompensuoti",
        "kompensacinis",
        "kompetencija",
        "kompetencija",
        "kompetentingas",
        "nepasitenkinimas",
        "papildyti",
        "papildomas",
        "visiškai",
        "išsamumas",
        "užbaigti",
        "užbaigimas",
        "laikymasis",
        "atitinka reikalavimus",
        "NO TRANSLATION",
        "sudarytas",
        "kompozitorius",
        "ramybė",
        "suvokti",
        "išsamus",
        "Draugas",
        "koncentrinis",
        "taikinimo procedūra",
        "sudaryti",
        "susitarimas",
        "atitikimas",
        "užuojautą",
        "pasveikinti",
        "palankus",
        "laidumas",
        "konfederacija",
        "pasitikėjimas",
        "įsitikinęs",
        "patvirtintas",
        "atitiktis",
        "draugiškas",
        "sveikinu",
        "susirinkimas",
        "kongruencija",
        "žinovas",
        "sąžinė",
        "sąžiningas",
        "sąmonė",
        "pašventinimas",
        "išsaugojimas",
        "konservuoti",
        "didelis",
        "dėmesingas",
        "nuoseklumas",
        "konsolė",
        "konsonantas",
        "pastovumas",
        "pastovi",
        "konstitucinis",
        "statyti",
        "baigti",
        "kontaktas",
        "apmąstymas",
        "turinys",
        "Tęsti",
        "kontūras",
        "prisidėti",
        "pagalbininkas",
        "patogumas",
        "patogus",
        "vienuolynas",
        "konvencija",
        "žinoma",
        "pokalbis",
        "Paversti",
        "įtikinti",
        "Saunus",
        "vėsa",
        "bendradarbiauti",
        "bendradarbiauja",
        "bendradarbiavimas",
        "kooperatyvas",
        "branduolys",
        "karūnavimas",
        "korporacija",
        "kūniškas",
        "taisomasis",
        "korespondencija",
        "patvirtinti",
        "kosmopolitinis",
        "jaukus",
        "taryba",
        "advokatas",
        "patarėjas",
        "suskaičiuoti",
        "grafionė",
        "drąsos",
        "drąsus",
        "mandagus",
        "mandagumas",
        "Laisvalaikis",
        "kava",
        "Sandorą",
        "lopšys",
        "laivas",
        "meistras",
        "grietinėlė",
        "sukurti",
        "kūrybingas",
        "patikimumas",
        "pažymėjimai",
        "patikimumas",
        "patikimas",
        "kreditas",
        "NO TRANSLATION",
        "įskaityta",
        "crescendo",
        "kritika",
        "vainikuoja",
        "labai svarbu",
        "kristalas",
        "apsiausti",
        "kulinarija",
        "kulminacija",
        "kultivuoti",
        "kultivuojamas",
        "auginimas",
        "kultūra",
        "išgydomas",
        "smalsumas",
        "garbanoti",
        "pagalvėlė",
        "klientas",
        "mielas",
        "pjaustytuvai",
        "dame",
        "šokis",
        "drąsus",
        "brangioji",
        "baisus",
        "dukra",
        "Aušra",
        "spręsti",
        "brangioji",
        "diskusija",
        "padorumas",
        "padorus",
        "deklaracinis",
        "atsidavimas",
        "ginti",
        "ginti",
        "gynėjas",
        "ginti",
        "gynyba",
        "pagarba",
        "galutinis",
        "laipsnis",
        "patrauklus",
        "deleguoti",
        "sąmoningas",
        "skanus",
        "malonumas",
        "malonu",
        "puikūs",
        "Išlaisvinimas",
        "pristatymas",
        "demokratija",
        "įrodomas",
        "demonstracinis",
        "gylis",
        "apibūdinantis",
        "nusipelno",
        "nusipelnė",
        "dizaineris",
        "pageidautina",
        "norintis",
        "nori",
        "Kelionės tikslas",
        "aptikti",
        "aptikimas",
        "nustatymas",
        "Atkaklus",
        "plėtoti",
        "religinis",
        "pašventintas",
        "taupumas",
        "deimantas",
        "dienoraštis",
        "žodynas",
        "didaktinis",
        "mityba",
        "oriai",
        "orumas",
        "kruopštumas",
        "vakarienė",
        "diplomatija",
        "diplomatinis",
        "direktorius",
        "atradimas",
        "NO TRANSLATION",
        "diskrecija",
        "diskrecinis",
        "diskusija",
        "dezinfekavimas",
        "išmesti",
        "skleisti",
        "distiliavimas",
        "skirtumas",
        "dutty",
        "diversifikuota",
        "nukreipimas",
        "dieviškumas",
        "gydytojas",
        "atlikėjas",
        "užsispyręs",
        "delfinas",
        "don",
        "donorystė",
        "neabejotinai",
        "balandis",
        "žemas",
        "duetas",
        "kunigaikštis",
        "patvarumas",
        "patvarus",
        "tinkamas",
        "nori",
        "troškimas",
        "Earl",
        "uždirbti",
        "rimtai",
        "sąžiningai",
        "nuoširdumas",
        "lengvumas",
        "servitutas",
        "NO TRANSLATION",
        "valgyti",
        "ekstazis",
        "ekstazinis",
        "ugdymas",
        "auklėti",
        "išsilavinę",
        "švietimo",
        "efektyvus",
        "veiksmingumas",
        "efektyvumas",
        "efektyvus",
        "pastangos",
        "ejakuliacija",
        "kūrimas",
        "išaukštintas",
        "vyresnysis",
        "vyresnieji",
        "išsirinkti",
        "elektrinis",
        "elektra",
        "elegancija",
        "elegantiškas",
        "aukštis",
        "tinkamas",
        "elitas",
        "iškalba",
        "iškalbingas",
        "išsiaiškinti",
        "emancipacija",
        "apsirengti",
        "emeritas",
        "Eminence",
        "iškilmingas",
        "išskirtinai",
        "NO TRANSLATION",
        "empatija",
        "suteikti galios",
        "imuliuoti",
        "įgalinti",
        "įgalinimas",
        "enchant",
        "enchanted",
        "enchanting",
        "NO TRANSLATION",
        "paskatinti",
        "skatinimas",
        "enciklopedija",
        "stengtis",
        "duoti",
        "apdovanotas",
        "apdovanojimas",
        "ištvermė",
        "iškęsti",
        "energingas",
        "užsiima",
        "patrauklus",
        "padidinti",
        "mėgautis",
        "mėgaujuosi",
        "apšviesti",
        "apšvietimas",
        "pagyvinti",
        "praturtinkite",
        "ansamblis",
        "ženminbi",
        "iniciatyvus",
        "pramogauti",
        "pramogauti",
        "linksmas",
        "pramogos",
        "entuziazmas",
        "entuziastas",
        "NO TRANSLATION",
        "efemeridai",
        "epinis",
        "epitome",
        "lygybė",
        "lygiai taip pat",
        "pusiausvyra",
        "nuosavybė",
        "pavedimas",
        "eruditas",
        "espritas",
        "esminis",
        "įsteigta",
        "pagarba",
        "estetinis",
        "etiška",
        "Etika",
        "visada žalia",
        "amžinai",
        "Akivaizdu",
        "evoliucija",
        "pagirti",
        "išaukštinimas",
        "išaukštintas",
        "viršyti",
        "puikiai",
        "kompetencija",
        "puikiai",
        "keistis",
        "patrauklus",
        "sužadinimas",
        "sužadinti",
        "susijaudinęs",
        "jaudulys",
        "įdomus",
        "pavyzdinis",
        "atleidimas nuo mokesčio",
        "linksmas",
        "prašau",
        "raginimas",
        "egzistavimas",
        "egzotiškas",
        "tikėtis",
        "lūkesčiai",
        "tikslinga",
        "ekspedicija",
        "Patyręs",
        "ekspertas",
        "patirtis",
        "paaiškinti",
        "puikūs",
        "puikiai",
        "išplėsti",
        "platus",
        "papildomai",
        "nepaprastas",
        "ištraukti",
        "pasipiktinimas",
        "palengvinti",
        "faktai",
        "fakultetas",
        "NO TRANSLATION",
        "šviesus",
        "teisingai",
        "tikėjimas",
        "Ištikimas",
        "šlovė",
        "pažįstamas",
        "pažintis",
        "garsus",
        "žinoma",
        "išgalvotas",
        "fanfare",
        "patraukliai",
        "susižavėjimas",
        "madinga",
        "beprotiška",
        "palankus",
        "mėgstamiausia",
        "favoritizmas",
        "bebaimis",
        "žygdarbis",
        "funkcija",
        "felicity",
        "kolega",
        "bendravimas",
        "Moteris",
        "derlingas",
        "pasigailėjimas",
        "festivalis",
        "šventinis",
        "NO TRANSLATION",
        "ištikimybė",
        "fiesta",
        "pagaliau",
        "puošmena",
        "malonumas",
        "bolidas",
        "ugniai atsparus",
        "tvirtumas",
        "NO TRANSLATION",
        "montavimas",
        "šviestuvas",
        "glostantis",
        "laivynas",
        "lankstumas",
        "gėlių",
        "srautas",
        "gėlėtas",
        "praplaukite",
        "skraidantis",
        "sutelkti dėmesį",
        "malonumas",
        "maistas",
        "futbolas",
        "pasipriešinimas",
        "fore",
        "protėviai",
        "pirmiau nurodyta",
        "Meistras",
        "pirmtakas",
        "numatyti",
        "numatytas",
        "numatymas",
        "kalti",
        "atleisk",
        "atleista",
        "atleiskis",
        "formuojantis",
        "formulė",
        "NO TRANSLATION",
        "ateityje",
        "sustiprinti",
        "tvirtumas",
        "tvirtovė",
        "laimingas",
        "likimas",
        "Persiųsti",
        "rasta",
        "fondas",
        "kvapnus",
        "atviras",
        "atvirumas",
        "broliškas",
        "laisvė",
        "laisvai",
        "draugas",
        "patogumas",
        "draugiškas",
        "Draugystė",
        "bjaurus",
        "susižavėti",
        "taupus",
        "vaisingas",
        "įvykdyti",
        "įvykdymas",
        "pilnas",
        "visiškai",
        "linksma",
        "pagrindinis",
        "lydusis saugiklis",
        "sintezė",
        "pelnas",
        "įgyti",
        "galanti",
        "talentingumas",
        "daug",
        "sodas",
        "granatas",
        "garnisonas",
        "leidinys",
        "įrankis",
        "perlas",
        "apskritai",
        "dosnumas",
        "turtinga",
        "gilus",
        "genijus",
        "genteel",
        "džentelmenis",
        "švelnumas",
        "bajorai",
        "tikra",
        "geranium",
        "dovana",
        "talentingas",
        "milžiniškas",
        "giggle",
        "sija",
        "duoti",
        "malonu",
        "džiaugsmas",
        "linksma",
        "slide",
        "žvilgsnis",
        "blizgantis",
        "šlovinimas",
        "šlovink",
        "šlovė",
        "blizgesys",
        "švyti",
        "žėrintis",
        "dievas",
        "dievobaimingas",
        "pasiaukojimas",
        "auksas",
        "Gerai",
        "gerai",
        "gerumas",
        "prekės",
        "prestižas",
        "spalvingas",
        "Evangelija",
        "valdyti",
        "malonė",
        "grakštus",
        "maloningas",
        "maloniai",
        "baigimas",
        "anūkai",
        "didybė",
        "močiutė",
        "dotacija",
        "suteiktas",
        "dėkingas",
        "patenkinti",
        "dėkingumas",
        "didesnis",
        "didybė",
        "žalias",
        "pasveikinimas",
        "genialus",
        "šypsnys",
        "sūdyti",
        "smėlis",
        "pagrindas",
        "augti",
        "augimas",
        "garantija",
        "apsauga",
        "globėjas",
        "globa",
        "gubernatoriaus",
        "patarimai",
        "gidas",
        "vadovas",
        "guru",
        "žarnas",
        "gimnazija",
        "buveinė",
        "Hale",
        "patogus",
        "laimingai",
        "laimė",
        "laimingas",
        "atsparus",
        "harmoningai",
        "harmonija",
        "derlius",
        "haven",
        "pažanga",
        "Išgyti",
        "gijimas",
        "sveikas",
        "sveikas",
        "nuoširdus",
        "židinys",
        "nuoširdžiai",
        "dangus",
        "dangus",
        "pakilimas",
        "šalmas",
        "pagalbininkas",
        "naudinga",
        "žolelių",
        "herojus",
        "herojiškas",
        "didvyriškumas",
        "herojė",
        "herojiškumas",
        "atsipalaidavimas",
        "linksmas",
        "linksmas",
        "samdyti",
        "hobis",
        "šventė",
        "šventumas",
        "šventas",
        "pagarba",
        "homologija",
        "nuoširdus",
        "sąžiningumas",
        "medus",
        "medaus mėnuo",
        "garbė",
        "garbingas",
        "tikiuosi",
        "viltis",
        "horizontas",
        "svetingumas",
        "namų ūkis",
        "namų ūkis",
        "apkabinti",
        "humaniškas",
        "humanitariniai",
        "žmonija",
        "nuolankus",
        "nuolankiai",
        "nuolankumas",
        "humoristas",
        "humoristinis",
        "hurray",
        "gyvulininkystė",
        "skubėti",
        "namelis",
        "higieniškas",
        "himnas",
        "idealizmas",
        "stabas",
        "NO TRANSLATION",
        "apšvietimas",
        "iliustruoti",
        "garsus",
        "vaizduotė",
        "nepriekaištingas",
        "didžiulis",
        "pasinerti",
        "nemirtingas",
        "skleisti",
        "nešališkas",
        "nešališkumas",
        "nepriekaištinga",
        "nepralaidus",
        "svarba",
        "svarbu",
        "įspūdį",
        "įspūdis",
        "pagerinti",
        "patobulintas",
        "tobulinimas",
        "tobulinimas",
        "improvizuoti",
        "neatsiejama",
        "inauguracija",
        "įžambinis",
        "įtraukti",
        "įskaitant",
        "įskaitant",
        "imtinai",
        "padidinti",
        "neištrinama",
        "kompensacija",
        "nepriklausomybė",
        "nesunaikinamas",
        "individualumas",
        "nepaklusnus",
        "neapsakomas",
        "nebrangus",
        "neklystantis",
        "kūdikis",
        "begalinis",
        "begalybė",
        "įtakingas",
        "informacija",
        "gudrus",
        "paveldėjimas",
        "nepakartojamas",
        "nekaltumas",
        "nekaltas",
        "nekaltai",
        "nekenksmingas",
        "naujoves",
        "naujovės",
        "klausytojas",
        "tyrimas",
        "smalsus",
        "neatsiejama",
        "simbolika",
        "inspektorius",
        "įkvėpimas",
        "įkvėpti",
        "Įkvėptas",
        "instinktyvus",
        "pavesti",
        "instrukcija",
        "instruktorius",
        "instrumental",
        "apdrausti",
        "nepažeistas",
        "vientisumas",
        "intelektas",
        "intelektualus",
        "žvalgyba",
        "protingas",
        "numatytas",
        "bendravimas",
        "palūkanos",
        "suinteresuotas",
        "įdomus",
        "interjeras",
        "tarpinis",
        "interludas",
        "intymus",
        "intonacija",
        "bejėgis",
        "intuicija",
        "intuityvi",
        "visada",
        "išradingas",
        "išradėjas",
        "ištirti",
        "pagyvinti",
        "kvietimas",
        "pakviesti",
        "kviečiantis",
        "geležis",
        "nepatraukiamas",
        "neginčytinas",
        "jackpota",
        "džemas",
        "NO TRANSLATION",
        "darbas",
        "prisijungti",
        "prisijungė prie",
        "Jokeris",
        "juokauja",
        "žurnalistas",
        "kelionė",
        "Jovial",
        "džiaugsmas",
        "džiaugsmingas",
        "džiaugsmingas",
        "linksmas",
        "jubiliejus",
        "teisminis",
        "protingas",
        "šokinėti",
        "teisingumas",
        "pateisinamas",
        "pateisinimas",
        "laikyti",
        "ken",
        "pagrindinis žodis",
        "kertinis akmuo",
        "malonus",
        "gerumas",
        "giminingas",
        "karalius",
        "pabučiuoti",
        "kačiukas",
        "įgūdis",
        "riteris",
        "žinant",
        "žinios",
        "Kudos",
        "darbo",
        "ėriena",
        "žemė",
        "nusileido",
        "lazeris",
        "pagirtinas",
        "juoktis",
        "juokiasi",
        "juokas",
        "paleisti",
        "laureatas",
        "Laurynas",
        "laurus",
        "gausus",
        "teisėtas",
        "vadovauti",
        "lyderis",
        "lyga",
        "mokytis",
        "mokymasis",
        "dėstytojas",
        "laisvė",
        "teisėtas",
        "legalizuotas",
        "legendinis",
        "įskaitomumas",
        "įskaitomas",
        "laisvalaikis",
        "nesunkiai",
        "lemma",
        "švelnus",
        "pamoka",
        "su raidėmis",
        "lygis",
        "svertas",
        "išlaisvinti",
        "išlaisvinimas",
        "laisvė",
        "biblioteka",
        "gyvybės šaltinis",
        "švyturys",
        "patiko",
        "kalbininkas",
        "liūtas",
        "litas",
        "logiškas",
        "ilgaamžiškumas",
        "valdžia",
        "patraukli",
        "meilė",
        "mielas",
        "NO TRANSLATION",
        "meilužis",
        "myliu",
        "ištikimas",
        "lojalumas",
        "sėkmė",
        "laimingas",
        "saldus",
        "blizgesys",
        "blizgus",
        "prabangus",
        "prabangus",
        "prabanga",
        "lyra",
        "lyrinis",
        "stebuklinga",
        "magnetas",
        "magnetizmas",
        "magnetitas",
        "didybė",
        "puikus",
        "mergaitė",
        "pagrindinis",
        "pagrindas",
        "didingas",
        "didybė",
        "pagrindinis",
        "dauguma",
        "tvarkyti",
        "valdymas",
        "mandarinas",
        "vyriškumas",
        "pasireiškė",
        "vyriškas",
        "mana",
        "manieringas",
        "manieros",
        "gamintojas",
        "Kovas",
        "pažymėtas",
        "parduodamas",
        "marquis",
        "santuoka",
        "smegenys",
        "tuoktis",
        "Marshal",
        "stebuklas",
        "nuostabus",
        "stebuklingai",
        "vyriškas",
        "masažas",
        "meistras",
        "šedevras",
        "meistriškumas",
        "mate",
        "santuoka",
        "Matron",
        "maksimalus",
        "meras",
        "pieva",
        "matuojamas",
        "medalis",
        "tarpininkauti",
        "tarpininkavimas",
        "tarpininkas",
        "medicinos",
        "NO TRANSLATION",
        "Viduržemio jūros",
        "medley",
        "paminklas",
        "įsimintinas",
        "taisymas",
        "mėnesinės",
        "mentorius",
        "gailestingas",
        "gailestingumas",
        "sujungti",
        "nuopelnas",
        "nusipelnęs",
        "linksmas",
        "linksmas",
        "didmiestis",
        "mettle",
        "mikroskopija",
        "akušerija",
        "galingas",
        "mime",
        "įsimenamas",
        "žvilgsnis",
        "ministerija",
        "stebuklas",
        "stebuklingas",
        "ramybė",
        "misionierius",
        "modelis",
        "vidutiniškas",
        "moderatorius",
        "kuklus",
        "kuklumas",
        "impulsas",
        "piniginis",
        "pinigai",
        "vienuolis",
        "paminklas",
        "moralinis",
        "moralė",
        "moralės",
        "skiedinys",
        "motinystė",
        "motyvas",
        "kilnojamasis",
        "vežėjas",
        "raumeningas",
        "muzika",
        "muzikinis",
        "keičiamas",
        "abipusis",
        "nap",
        "gamtininkas",
        "plaukiojantis",
        "tvarkingai",
        "nektaras",
        "adata",
        "derėtis",
        "derybininkas",
        "kaimynas",
        "nervas",
        "nestle",
        "bajorai",
        "kilnus",
        "bajoras",
        "nominacija",
        "normalumas",
        "pastebimas",
        "žinomi žmonės",
        "NO TRANSLATION",
        "sąvoka",
        "mityba",
        "numeriai",
        "slaugytoja",
        "darželis",
        "ugdyti",
        "maistingas",
        "ąžuolas",
        "oazė",
        "priesaika",
        "paklusnumas",
        "tikslas",
        "privalomas",
        "stebėtinas",
        "gaunamas",
        "aiškus",
        "keleivis",
        "okupacija",
        "užimti",
        "pasiūlymas",
        "pareigūnas",
        "kompensuoti",
        "atšaka",
        "žinomas",
        "atvirumas",
        "opera",
        "tinkamas",
        "galimybė",
        "optimizmas",
        "optimistas",
        "pasirinkimas",
        "neprivaloma",
        "orakulas",
        "oracija",
        "orkestras",
        "ordinuotas",
        "tvarkingai",
        "ordinas",
        "ekologiškas",
        "organizacija",
        "organizuoti",
        "organizuotas",
        "orgazmas",
        "originalumas",
        "ornamentuotas",
        "ornate",
        "rezultatas",
        "pralenkti",
        "į išorę",
        "labai džiaugėsi",
        "didžiulis",
        "nuosavybė",
        "Ramiojo vandenyno regionas",
        "padas",
        "pamušalas",
        "irklas",
        "skanus",
        "paliatyvus",
        "panacėja",
        "panache",
        "NO TRANSLATION",
        "paprika",
        "paragonas",
        "svarbiausia",
        "atleisk man",
        "tėvystė",
        "parietalinis",
        "dalyvauti",
        "dalyvavimas",
        "partneris",
        "partnerystė",
        "aistra",
        "aistringas",
        "laisvalaikis",
        "pastorius",
        "pyragas",
        "ganykla",
        "patentas",
        "kantrybė",
        "pacientas",
        "patriarchalinis",
        "globėjas",
        "globoja",
        "sumokėti",
        "ramybė",
        "taikus",
        "taikus",
        "Povas",
        "keck",
        "ypatumas",
        "giminė",
        "neprilygstamas",
        "polinkis",
        "suvokti",
        "pastebimas",
        "daugiametis",
        "puikus",
        "tobulumas",
        "atlikėjas",
        "pasipriešinti",
        "leidimas",
        "tęstinumas",
        "atkaklumas",
        "nuolatinis",
        "asmeniškai",
        "tinkamas",
        "farmacinė",
        "filantropas",
        "filantropija",
        "filosofas",
        "phoenix",
        "fonetinis",
        "gydytojas",
        "fizika",
        "fiziologija",
        "kūno sudėjimas",
        "pasiimti",
        "iškylai",
        "vaizdingas",
        "pamaldumas",
        "pigułka",
        "pagalvė",
        "pilotas",
        "pinnacle",
        "pionierius",
        "dievobaimingas",
        "šerdis",
        "šerdesas",
        "mielas",
        "planavimas",
        "žaismingas",
        "žaidimų aikštelė",
        "playhouse",
        "malonus",
        "malonu",
        "malonus",
        "įkeitimas",
        "plenarinis posėdis",
        "gausu",
        "putplastis",
        "slyva",
        "plūgas",
        "pliušas",
        "sluoksnis",
        "žymiai",
        "policija",
        "policininkas",
        "lenkas",
        "poliruotas",
        "mandagus",
        "mandagumas",
        "NO TRANSLATION",
        "baseinas",
        "popiežius",
        "populiarumas",
        "populiarinamas",
        "gyventojai",
        "nešiojamasis",
        "turėti",
        "geriamasis",
        "stiprumas",
        "galingas",
        "galingai",
        "praktika",
        "praktikuojama",
        "praktika",
        "pagirti",
        "gyrė",
        "pagirtinas",
        "melstis",
        "atsargumo priemonė",
        "prieš tai",
        "pirmenybė",
        "brangioji",
        "tikslus",
        "tikslumas",
        "prisirišimas",
        "vyrauja",
        "vyresnysis",
        "norėčiau",
        "Premier",
        "patalpos",
        "paruoškite",
        "paruošta",
        "senovinis",
        "buvimas",
        "pateikti",
        "vaizduojamas",
        "konservantas",
        "išsaugoti",
        "prezidentas",
        "prestižas",
        "presto",
        "graži",
        "vyrauti",
        "prevencija",
        "neįkainojamas",
        "pasididžiavimas",
        "kunigas",
        "kunigystė",
        "kunigai",
        "pirmenybė",
        "pirminis",
        "pagrindinis",
        "gruntas",
        "princas",
        "princis",
        "princesė",
        "pagrindinis",
        "senovinis",
        "privilegijuotas",
        "teisingumas",
        "procedūra",
        "procesija",
        "Proctor",
        "įsigyti",
        "nuostabus",
        "prodigy",
        "gamintojas",
        "gaminti",
        "gamyba",
        "produktyvus",
        "našumas",
        "profesija",
        "profesionalus",
        "profesorius",
        "mokėjimas",
        "įgudęs",
        "gausus",
        "progresas",
        "progresija",
        "laipsniškas",
        "vaisingas",
        "pagarba",
        "akivaizdžiai",
        "pažadas",
        "perspektyvus",
        "skatinimas",
        "prop",
        "tinkamas",
        "pranašas",
        "profilaktinis",
        "pasiūlymas",
        "perspektyva",
        "klestėti",
        "gerovė",
        "klestintis",
        "apsaugoti",
        "apsauga",
        "apsauginis",
        "apsauga",
        "didžiuojasi",
        "įrodyti",
        "patarlė",
        "numatyti",
        "teikimas",
        "atsargumas",
        "apdairus",
        "psalmė",
        "visuomenė",
        "traukti",
        "kanceliarija",
        "punktualus",
        "punktualumas",
        "šuniukas",
        "grynai",
        "valymas",
        "valyti",
        "puristė",
        "Grynumas",
        "purr",
        "Keista",
        "kvalifikuotas",
        "kvalifikacinis",
        "ieškojimas",
        "klausimas",
        "greitis",
        "atsipalaidavęs",
        "tylus",
        "chininas",
        "spinduliavimas",
        "spinduliavimas",
        "spinduliuoja",
        "radijas",
        "rapt",
        "pasipiktinimas",
        "racionalus",
        "skaitytojas",
        "lengvai",
        "pasirengimas",
        "skaitymas",
        "dar kartą patvirtina",
        "tikras",
        "priežastis",
        "pasitikėjimas",
        "nuraminti",
        "nuolaida",
        "nauja redakcija",
        "gavo",
        "gavimo",
        "NO TRANSLATION",
        "abipusis",
        "melioracija",
        "atsistoti",
        "atpažįstamas",
        "rekomenduoti",
        "Susitaikymas",
        "persvarstymas",
        "rekonstruoti",
        "rekonstrukcija",
        "įrašymo įrenginys",
        "susigrąžinti",
        "atkūrimas",
        "poilsis",
        "rekreacinė",
        "ištaisyti",
        "išpirkimas",
        "žalos atlyginimas",
        "tobulinti",
        "tobulinimas",
        "reforma",
        "reformacija",
        "reformatorė",
        "gaivus",
        "atnaujinti",
        "Regal",
        "regentas",
        "reguliarumas",
        "reguliuoti",
        "reabilituoti",
        "reabilitacija",
        "grąžinti",
        "kompensavimas",
        "stiprinimas",
        "atkurti",
        "džiaugtis",
        "džiaugsmas",
        "atgaivinti",
        "atjaunintas",
        "atsipalaidavimas",
        "Aktualus",
        "patikimumas",
        "patikimas",
        "pasitikėjimas",
        "palengvėjimas",
        "atleidžiantis",
        "perdaryti",
        "nuostabus",
        "NO TRANSLATION",
        "ištaisyti",
        "atsisakymas",
        "pertvarkyti",
        "renesansas",
        "padengti",
        "atnaujinimas",
        "atnaujinti",
        "renovacija",
        "žinomas",
        "žinomas",
        "reorganizuoti",
        "atlyginimas",
        "grąžinti",
        "atgailauti",
        "papildyti",
        "pakartotinai",
        "reporteris",
        "atsipalaiduoti",
        "atstovaujama",
        "reprodukcinis",
        "gerbiamas",
        "gelbėjimas",
        "rezervas",
        "rezidentas",
        "atsparus",
        "varža",
        "ryžtingai",
        "ištekliai",
        "pagarba",
        "garbingumas",
        "garbingas",
        "Pagarbiai",
        "gerbti",
        "pagarba",
        "kvėpuoti",
        "blizgantis",
        "atsakingas",
        "reaguoja",
        "poilsis",
        "ramus",
        "restitucija",
        "atkuriamasis",
        "atstatymas",
        "apribojimas",
        "atnaujinimas",
        "sulaikymas",
        "susivienijimas",
        "atsipalaiduoti",
        "revels",
        "gerbti",
        "pagarba",
        "Prezidentas",
        "Reverie",
        "peržiūrėkite",
        "atgimimas",
        "revoliucinis",
        "atlygis",
        "ritmas",
        "ritminis",
        "juosta",
        "turtingumas",
        "raitelis",
        "teisus",
        "teisėtas",
        "teisingai",
        "prinokę",
        "sulaukti",
        "kyla",
        "kniedijimas",
        "rodsteris",
        "tvirtas",
        "Rokas",
        "strypas",
        "ritulys",
        "romantika",
        "romantiškas",
        "romantizmas",
        "romp",
        "įsišaknijusi",
        "rožinis",
        "rota",
        "įprastas",
        "honoraras",
        "rubrika",
        "ruta",
        "saugus",
        "apsauga",
        "išmintis",
        "šventasis",
        "šventasis",
        "atlyginimas",
        "ryškus",
        "sveikas",
        "sveikinimas",
        "išganymas",
        "salve",
        "samurajus",
        "pašventinimas",
        "pašventinti",
        "šventykla",
        "Sanguine",
        "sanitarinis",
        "satin",
        "patenkinamai",
        "patenkintas",
        "sutaupyti",
        "taupymas",
        "išgirsti",
        "pikantiškas",
        "išmintis",
        "mokslininkas",
        "stipendija",
        "mokslinis",
        "mokslininkas",
        "NO TRANSLATION",
        "rezultatas",
        "Raštininkas",
        "scenarijus",
        "nuostabus",
        "skulptūra",
        "jūra",
        "antspaudas",
        "prieskoniais",
        "sekretoriatas",
        "darbo stažas",
        "sensacingas",
        "prasme",
        "jautrumas",
        "protingai",
        "jausmingumas",
        "jausmingas",
        "sentimentalus",
        "sentimentalumas",
        "sargybinis",
        "ramybė",
        "pamokslas",
        "serumas",
        "Įstatovas",
        "seksas",
        "figūra",
        "kietas",
        "Dalintis",
        "prieglauda",
        "piemenys",
        "šviesti",
        "spindi",
        "apsipirkti",
        "pečių",
        "protingas",
        "šilkas",
        "supaprastinti",
        "nuoširdus",
        "nuoširdumas",
        "dainuoti",
        "atskirai",
        "pone",
        "seserys",
        "kvalifikuotas",
        "sumanus",
        "dangus",
        "šiferis",
        "aptakus",
        "lieknas",
        "lieknas",
        "šypsena",
        "šypsosi",
        "sumuštas",
        "lygumas",
        "snaigė",
        "tylumas",
        "socialus",
        "paguoda",
        "kareivis",
        "tvirtas",
        "tvirtumas",
        "tirpalas",
        "mokumas",
        "sonaras",
        "sonata",
        "sonetas",
        "skambesys",
        "nuraminti",
        "raminantis",
        "NO TRANSLATION",
        "tvirtumas",
        "sriuba",
        "SPA",
        "erdvus",
        "spanielis",
        "spindesys",
        "ypatingas",
        "NO TRANSLATION",
        "kalba",
        "greitas",
        "tarimas",
        "prieskonis",
        "dvasia",
        "spiritai",
        "nuostabus",
        "didybė",
        "rėmėjas",
        "tyliai",
        "sutuoktinis",
        "Eglė",
        "stabilus",
        "staccato",
        "nerūdijantis",
        "eržilas",
        "stalwart",
        "ištvermė",
        "stovintis",
        "žvaigždė",
        "žvaigždutė",
        "žvaigždė",
        "didingas",
        "pareiškimas",
        "statula",
        "statusas",
        "tvirtas",
        "tvirtas",
        "žvaigždė",
        "valdytojas",
        "tamsumas",
        "parduotuvė",
        "paprasta",
        "strateginis",
        "strategas",
        "jėga",
        "stiprinti",
        "stiprinti",
        "ryškus",
        "nuostabiai",
        "stipriai",
        "struktūra",
        "stud",
        "studijuoti",
        "tvirtas",
        "sublimacija",
        "medžiaga",
        "esminis",
        "pasisekė",
        "sėkmingai",
        "sėkmė",
        "sėkmingas",
        "glausta",
        "pakankamumas",
        "cukrus",
        "tinkamas",
        "švelnus",
        "saulė",
        "saulėtas",
        "saulėlydis",
        "saulės šviesa",
        "puikiai",
        "pernelyg žmogus",
        "pranašesnis",
        "pranašumas",
        "supermenas",
        "superžvaigždė",
        "malda",
        "reikmenys",
        "tiekimas",
        "palaikoma",
        "rėmėjas",
        "palaikymas",
        "aukščiausias",
        "puikiai",
        "laidavimas",
        "prielaidą",
        "pranoksta",
        "siurprizas",
        "geodezija",
        "išgyventi",
        "prisiekti",
        "saldus",
        "brangioji",
        "saldainis",
        "saldumas",
        "saldumynai",
        "greitas",
        "plaukti",
        "simbolinis",
        "simetriškas",
        "simetrija",
        "simpatiškas",
        "užuojautą",
        "simfonija",
        "sinchronizuoti",
        "sinergetinis",
        "Sinodas",
        "taktas",
        "pasaka",
        "talentas",
        "talismanas",
        "kalbėti",
        "raugintos",
        "užduotis",
        "skoningas",
        "skanus",
        "mokyti",
        "mokytojas",
        "technologija",
        "nuolankumas",
        "grūdintas",
        "tvirtas",
        "tvirtas",
        "tvirtumas",
        "nuoma",
        "nuomininkas",
        "švelnus",
        "švelnumas",
        "dėkingas",
        "padėka",
        "teorinis",
        "terapinis",
        "terapija",
        "NO TRANSLATION",
        "grynakraujis",
        "sąmoningas",
        "sąmojingas",
        "taupymas",
        "jaudulys",
        "jaudinantis",
        "klesti",
        "sostas",
        "pakelti",
        "plyteles",
        "laiku",
        "milteliai",
        "pavadinimas",
        "skrudinta duona",
        "tolerantiškas",
        "tolerancija",
        "viršuje",
        "tvirtumas",
        "bokštas",
        "baisus",
        "tradicinis",
        "ramus",
        "ramybė",
        "transcendencija",
        "transcendentinis",
        "keliauti",
        "lobis",
        "medis",
        "nepaprastai",
        "tendencija",
        "madinga",
        "intakas",
        "duoklė",
        "trig",
        "triumfas",
        "triumfuoja",
        "trofėjus",
        "paliaubas",
        "TIESA",
        "patikimas",
        "tiesa",
        "teisingumas",
        "globos įstaiga",
        "mokytojas",
        "dvynukas",
        "mirkčioti",
        "galiausiai",
        "teisėjas",
        "vieningumas",
        "Anonimas",
        "nepagrįstas",
        "nešališkas",
        "nepažeistas",
        "nepažeistas",
        "neribotas",
        "pabrėžti",
        "suprasti",
        "apdrausti",
        "nedalomas",
        "nemirtingas",
        "nedviprasmiškai",
        "atsiskleisti",
        "suvienijimas",
        "vienodai",
        "neinfekuota",
        "Unikalus",
        "unison",
        "vienarūšis",
        "united",
        "vienybė",
        "universitetas",
        "neribotas",
        "nepretenzingas",
        "neginčytinas",
        "neabejotinai",
        "neginčijamas",
        "neapsaugotas",
        "nesavanaudiška",
        "neprilygstamas",
        "tvirtas",
        "pakilimas",
        "vertikaliai",
        "naudingumas",
        "asheras",
        "įprasta",
        "naudingumas",
        "utopinis",
        "atostogos",
        "vakcina",
        "drąsus",
        "NO TRANSLATION",
        "vertingas",
        "avangardas",
        "nugalėti",
        "aksomas",
        "švelnus",
        "gerbiamas",
        "pagarba",
        "teisingumas",
        "verdant",
        "patikrinimas",
        "patikrinta",
        "tiesa",
        "tiesa",
        "verdantis",
        "verve",
        "veteranas",
        "Vakaras",
        "nugalėtojas",
        "pergalingas",
        "pergalė",
        "budrumas",
        "budrus",
        "energija",
        "energingas",
        "kaimo gyventojas",
        "patvirtinta",
        "atmetimas",
        "pirmoji",
        "nekaltybė",
        "dorybė",
        "dorybingas",
        "vizija",
        "vizionierius",
        "aplankyti",
        "lankytojas",
        "gyvybiškai svarbus",
        "gyvybingumas",
        "linksmas",
        "ryškus",
        "žodynas",
        "savanoris",
        "linksmas",
        "garantuoti",
        "pažadu",
        "darbo užmokestis",
        "garantija",
        "karys",
        "sargas",
        "budrus",
        "sargas",
        "atsparus vandeniui",
        "turtas",
        "atsparus oro sąlygoms",
        "pasveikino",
        "balta",
        "baltumas",
        "sveikas",
        "varteliai",
        "plačiai paplitęs",
        "noriai",
        "noras",
        "nepaprastas",
        "nugalėtojas",
        "laimėti",
        "laimėjimai",
        "bevielis",
        "wis",
        "išmintis",
        "protingas",
        "wit",
        "atlaikyti",
        "protas",
        "sąmojingas",
        "burtininkas",
        "įsčiose",
        "nuostabus",
        "nuostabiai",
        "nuostabus",
        "žodis",
        "dirba",
        "garbinimas",
        "verta",
        "vertas",
        "wot",
        "rašytojas",
        "jaunas",
        "jaunesnis",
        "jaunimas",
        "uolumas",
        "uolus",
        "zest",
    ]
)

_negative = set(
    [
        "apleisti",
        "paliktas",
        "atsisakymas",
        "pagrobimas",
        "netinkamas",
        "aberacija",
        "šmeižti",
        "nepatogus",
        "abject",
        "nenormalus",
        "panaikinti",
        "panaikinimas",
        "bjaurus",
        "bjaurystė",
        "nutraukti",
        "abortas",
        "neveikianti",
        "trintis",
        "atšaukti",
        "pūlinys",
        "nebuvimas",
        "nėra",
        "absentee",
        "nebuvimas",
        "absurdas",
        "absurdas",
        "piktnaudžiavimas",
        "apgailėtinas",
        "bedugnė",
        "avarija",
        "atsitiktinis",
        "prakeiktas",
        "kaltinimas",
        "kaltinamasis",
        "kaltinamas",
        "kaltinamasis",
        "kaltinamas",
        "skauda",
        "skausmas",
        "rūgštis",
        "ginčytinas",
        "papildiklis",
        "priklausomybė",
        "riebaluotas",
        "nuspręsti",
        "įspėjimas",
        "adrift",
        "suklastotas",
        "svetimavimu",
        "priešas",
        "neigiamas",
        "nelaimė",
        "nerimauti",
        "nukentėjęs",
        "nelaimė",
        "apgauti",
        "išsigandęs",
        "pasekmės",
        "poskonis",
        "sustiprėja",
        "sunkinantis",
        "pablogėjimas",
        "agresija",
        "agresyvus",
        "agresoriaus",
        "pyktis",
        "susijaudinęs",
        "agitacija",
        "agonizing",
        "agonija",
        "miške",
        "ail",
        "sergantis",
        "begalinis",
        "airs",
        "signalizacija",
        "nerimą keliantis",
        "alkoholizmas",
        "užsienietis",
        "atsikratyti",
        "pašalintas",
        "atsiskyrimas",
        "alimentai",
        "tvirtinimas",
        "pasakyk",
        "atskirai",
        "pasikeitimas",
        "dviprasmiškas",
        "pasala",
        "amnezija",
        "amfetaminai",
        "Anaconda",
        "analinis",
        "anarchizmas",
        "anarchistas",
        "anarchija",
        "Anathema",
        "senovės",
        "pyktis",
        "angina",
        "žvejyba",
        "piktas",
        "sielvartas",
        "priešiškumas",
        "animusas",
        "sunaikinti",
        "sunaikintas",
        "sunaikinimas",
        "erzina",
        "erzina",
        "erzina",
        "atšaukti",
        "panaikinimas",
        "anomalija",
        "Anoniminis",
        "antagonizmas",
        "antagonistas",
        "antagonistinis",
        "Siurbimas",
        "antikristas",
        "antipatija",
        "senovinis",
        "antisocialas",
        "antitezė",
        "nerimas",
        "nerimas",
        "apache",
        "apatiškas",
        "apatija",
        "aphid",
        "baisus",
        "apendicitas",
        "susirūpinimą",
        "nerimauja",
        "asignavimas",
        "archajiškas",
        "sunkus",
        "ginčytis",
        "argumentas",
        "argumentuotas",
        "sausas",
        "ginkluote",
        "kaltinimas",
        "įsiskolinimas",
        "areštas",
        "arogancija",
        "arogantiškas",
        "arsenas",
        "padegimas",
        "artilerija",
        "pelenai",
        "sugėdintas",
        "pelenai",
        "asilas",
        "užmušti",
        "užpuolikas",
        "Assassin",
        "nužudyti",
        "nužudymas",
        "puolimas",
        "asilas",
        "klaidinga",
        "sutraukiantis",
        "prieglobstis",
        "Ateizmas",
        "aterosklerozė",
        "žiaurus",
        "žiaurumas",
        "atrofija",
        "ataka",
        "puola",
        "susilpnintas",
        "silpninimas",
        "drąsumas",
        "austere",
        "taupymas",
        "autokratiškas",
        "autopsija",
        "lavina",
        "avarija",
        "keršytojas",
        "nepasitenkinimas",
        "nepasitenkinimas",
        "vengti",
        "vengimas",
        "baisus",
        "nepatogumas",
        "bjaurus",
        "skamba",
        "šūdas",
        "babuonas",
        "atgal",
        "atgal",
        "užtvankos",
        "bakterijos",
        "NO TRANSLATION",
        "blogai",
        "barberis",
        "blogai",
        "blogybė",
        "antstolis",
        "masalas",
        "ritinys",
        "balkas",
        "NO TRANSLATION",
        "banditas",
        "buna",
        "sprogti",
        "bangeris",
        "pašalinti",
        "ištremtas",
        "išvedimas",
        "bankrotas",
        "bankrotas",
        "banshee",
        "barb",
        "barbaras",
        "barbariškas",
        "barbarizmas",
        "žievė",
        "draudžiama",
        "nevaisingas",
        "barikadas",
        "barjeras",
        "be pagrindo",
        "bastard",
        "tešlą",
        "sumuštas",
        "baterija",
        "mūšis",
        "kovojo",
        "mūšio laukas",
        "bawdy",
        "bajonetas",
        "nešėjas",
        "žvėris",
        "bjaurus",
        "plakimas",
        "atsitikti",
        "prašau",
        "elgeta",
        "meldimas",
        "behemothas",
        "atrodo",
        "pavėluotas",
        "nuraminti",
        "karingasis",
        "diržas",
        "Bender",
        "prarasta",
        "praradimas",
        "nepasiekiamas",
        "Berserk",
        "žvėris",
        "išduoti",
        "išdavystė",
        "saugotis",
        "sumišimas",
        "šališkumas",
        "šališkas",
        "siaubti",
        "NO TRANSLATION",
        "fanatas",
        "fantazuoti",
        "tulžis",
        "biopsija",
        "beržas",
        "gimimo vieta",
        "kalė",
        "įkandimas",
        "kartaus",
        "kartumas",
        "keistas",
        "juoda",
        "Blackjack",
        "šantažas",
        "juodumas",
        "kaltinti",
        "nuobodus",
        "šventvagiškas",
        "šventvagystė",
        "sprogimas",
        "akivaizdus",
        "valyti",
        "blaze",
        "nuobodus",
        "kraujavimas",
        "trūkumas",
        "purvinas",
        "blighted",
        "aklas",
        "aklai",
        "aklai",
        "aklumas",
        "lizdinė plokštelė",
        "išpūstas",
        "BLOB",
        "blokada",
        "kraujo praliejimas",
        "kraujo įsivertinimas",
        "kruvinas",
        "blot",
        "pūstuvas",
        "išpūsti",
        "bliuzas",
        "blefas",
        "klaida",
        "blur",
        "neryškus",
        "susiraukti",
        "pasigyrimas",
        "pelkė",
        "fiktyvus",
        "virti",
        "boeliplate",
        "bomba",
        "bombarduoti",
        "bombardavimas",
        "bombardavo",
        "vergija",
        "obligacijos",
        "boo",
        "booby",
        "booze",
        "NO TRANSLATION",
        "nuobodulys",
        "nuobodu",
        "skolininkas",
        "nerimauti",
        "grisus",
        "apačioje",
        "privaloma",
        "bout",
        "galvijai",
        "berniukas",
        "boikotuoti",
        "pasidaryk",
        "brendis",
        "bravado",
        "sumušimas",
        "bjaurus",
        "pažeidimas",
        "palaužti",
        "siaubas",
        "NO TRANSLATION",
        "kyšis",
        "kyšininkavimas",
        "brigada",
        "siera",
        "šeriai",
        "palydovas",
        "broil",
        "sumušė",
        "sunaikintas",
        "bordelis",
        "mėlynė",
        "smūgis",
        "brutalus",
        "brutalumas",
        "brute",
        "bufetas",
        "klaida",
        "NO TRANSLATION",
        "svogūnas",
        "patyčias",
        "Bum",
        "bummeris",
        "našta",
        "biurokratija",
        "biurokratas",
        "įsilaužimas",
        "įsilaužimas",
        "laidojimas",
        "palaidotas",
        "burke",
        "sudegęs",
        "busted",
        "mėsininkas",
        "užpakalis",
        "buzzed",
        "cabal",
        "kakofonija",
        "Cad",
        "Cadaver",
        "narvas",
        "skaičiuojant",
        "NO TRANSLATION",
        "skambučiai",
        "kampanijas",
        "atšaukti",
        "vėžys",
        "atbaidyti",
        "kanibalas",
        "kanibalizmas",
        "NO TRANSLATION",
        "nelaisvėje",
        "nelaisvėje",
        "captor",
        "užfiksuoti",
        "skerdena",
        "karcinoma",
        "kardiomiopatija",
        "nerūpestingumas",
        "karikatūra",
        "kariesas",
        "skerdynės",
        "kūniškas",
        "mėsėdis",
        "kartelis",
        "atvejis",
        "karstas",
        "kastos",
        "nelaimingas atsitikimas",
        "katarakta",
        "katastrofa",
        "kateteris",
        "atsargiai",
        "pasitraukti",
        "kapinės",
        "cenzūra",
        "nepasitikėjimas",
        "cess",
        "nutraukimas",
        "pelagai",
        "švaistymas",
        "chagrin",
        "iššūkis",
        "chaosas",
        "chaotiškas",
        "šaradas",
        "apmokestinamas",
        "Vytis",
        "bausmė",
        "pokalbis",
        "pigus",
        "apgauti",
        "sūrio pyragas",
        "chicane",
        "vaikiškas",
        "šiltas",
        "chloroformas",
        "užspringti",
        "cholera",
        "supjaustyti",
        "nuobodi namų ruoša",
        "lėtinis",
        "cigarete",
        "šoktelėti",
        "susidūrimas",
        "susidūrimas",
        "kiškis",
        "vienuolynas",
        "debesuota",
        "debesuotumas",
        "clump",
        "gremėzdiškas",
        "kokainas",
        "priversti",
        "prievarta",
        "karstą",
        "šalta",
        "šaltai",
        "šaltis",
        "kolika",
        "žlugti",
        "susidūrimas",
        "sąmokslas",
        "koma",
        "komata",
        "kovoti",
        "kovotojas",
        "kareiviškas",
        "priėmimas",
        "neramumai",
        "komunizmas",
        "komunistas",
        "varzybos",
        "skųstis",
        "skundas",
        "kompleksinis",
        "sudėtingumas",
        "komplikuoja",
        "sudėtingas",
        "komplikacija",
        "kompostas",
        "prievarta",
        "privalomas",
        "paslėpti",
        "paslėpta",
        "paslėpimas",
        "įsivaizduoti",
        "tuštuma",
        "smegenų sukrėtimas",
        "pasmerkti",
        "pasmerkimas",
        "gailestingas",
        "nusivylimas",
        "prisipažinimas",
        "apsiriboti",
        "uždaras",
        "gimdymas",
        "konfiskuoti",
        "konfiskavimas",
        "gaisras",
        "konfliktas",
        "prieštaringas",
        "sumaišyti",
        "sugedo",
        "supainioti",
        "sumišimas",
        "grūstis",
        "kvailys",
        "užkariavimas",
        "sąmokslininkas",
        "sujaudinti",
        "sąmyšis",
        "vidurių užkietėjimas",
        "suvaržyti",
        "suvaržytas",
        "apribojimas",
        "užkratas",
        "užkrečiama",
        "užteršti",
        "užteršta",
        "užteršimas",
        "panieka",
        "panieka",
        "nusivylęs",
        "ginčytina",
        "kontrabanda",
        "sutartis",
        "prieštarauja",
        "prieštaravimas",
        "prieštaringas",
        "priešingai",
        "kontrastuotas",
        "prieštarauja",
        "pažeidimas",
        "prieštaringas",
        "nesutarimai",
        "kaltinamasis",
        "nuosprendis",
        "bendradarbiauti",
        "kopijuoti",
        "kopijuoti",
        "koroneris",
        "kūno skausmas",
        "lavonas",
        "pataisymas",
        "korozija",
        "ėsdinanti",
        "sugadintas",
        "sugadintas",
        "korupcija",
        "kosulys",
        "patarėjas",
        "judėjimas",
        "trokšta",
        "bailys",
        "bailys",
        "bailiai",
        "Crabby",
        "krekas",
        "krekingo",
        "krekingo",
        "mėšlungis",
        "tramdomas",
        "skriejikas",
        "Cranky",
        "šūdas",
        "avarija",
        "nuskaityti",
        "Crazed",
        "pamišęs",
        "šlubavimas",
        "tvarinys",
        "šliaužti",
        "nusikaltimas",
        "nusikalstamas",
        "nusikalstamumas",
        "Cringe",
        "kankinti",
        "suluošintas",
        "krizė",
        "traškus",
        "kritikas",
        "kritika",
        "kritikuoti",
        "klajoti",
        "kirsti",
        "sustorėjęs",
        "krikščionys",
        "nukryžiavimas",
        "žalios",
        "žiaurus",
        "žiauriai",
        "žiaurumas",
        "truputis",
        "krizė",
        "kryžiaus žygis",
        "susmulkintas",
        "griovimas",
        "kietas",
        "verkis",
        "verkimas",
        "kripta",
        "cuckold",
        "gegutė",
        "nuvalyti",
        "kaltė",
        "kaltinamas",
        "kaltininkas",
        "kulta",
        "sudėtinga",
        "puodelis",
        "cur",
        "prakeiksmas",
        "prakeiktas",
        "prakeikimas",
        "bjaurus",
        "pjaustytuvas",
        "pjūvis",
        "pjaustymas",
        "cianidas",
        "ciklonas",
        "cista",
        "citomegalovirusas",
        "dabbling",
        "daemonas",
        "daft",
        "kiškis",
        "žala",
        "žalos atlyginimas",
        "prakeiktas",
        "pasmerkimas",
        "pasmerktas",
        "slopintuvas",
        "pleiskanos",
        "dandy",
        "pavojus",
        "pavojingas",
        "tamsinti",
        "patamsintas",
        "tamsa",
        "briaunos",
        "netyčia",
        "priblokštas",
        "deaktyvuoti",
        "aklavietė",
        "mirtini",
        "kurtis",
        "mirtis",
        "debetas",
        "išblaškymas",
        "nuolaužos",
        "skola",
        "skolininkas",
        "skilimas",
        "išnykęs",
        "miręs",
        "apgaulė",
        "apgaulingas",
        "apgauti",
        "apgauti",
        "apgauti",
        "apgaulė",
        "apgaulingas",
        "deklinacija",
        "nuosmukis",
        "mažėja",
        "skilimas",
        "mažinti",
        "sumažėjimas",
        "nykimas",
        "sunaikinti",
        "atimti",
        "šmeižtas",
        "šmeižikiškas",
        "numatytas",
        "nugalėti",
        "nugalėjo",
        "defektas",
        "NO TRANSLATION",
        "defektinis",
        "neapsaugotas",
        "atidėjimas",
        "nepasitenkinimas",
        "iššaukiantis",
        "trūkumas",
        "trūkumas",
        "defluoti",
        "defliacija",
        "deformuoti",
        "deformuotas",
        "deformacija",
        "apgauti",
        "neveikianti",
        "iššaukti",
        "išnykimas",
        "išnykęs",
        "skilimas",
        "pabloginti",
        "žeminantis",
        "delsimas",
        "atidėtas",
        "žalingas",
        "ištrynimas",
        "nusikalstamumas",
        "nusikaltėlis",
        "nuobodus",
        "deliriumas",
        "debesis",
        "apgaulė",
        "klaidinantis",
        "paklausa",
        "reikalaujantis",
        "demented",
        "demencija",
        "žlugimas",
        "nugriauti",
        "griovimas",
        "demonas",
        "demoniškas",
        "demoralizuotas",
        "atsisakymas",
        "atmesta",
        "denonsuoti",
        "denonsavimas",
        "paneigti",
        "atmesti",
        "išvyko",
        "išvykimas",
        "priklausomybė",
        "priklausomybė",
        "apgailėtinas",
        "apgailestauju",
        "deportuoti",
        "deportacija",
        "iškraipytas",
        "nusikaltimas",
        "nusidėvėjimas",
        "nusidėvėjimas",
        "nusidėvėjimas",
        "prispausti",
        "depresija",
        "depresija",
        "depresija",
        "depresija",
        "atėmimas",
        "iškraipytas",
        "apleistas",
        "sumišimas",
        "nukrypimas",
        "žalingas",
        "nusivylimas",
        "dykuma",
        "apleistas",
        "desertion",
        "atmesti",
        "sunaikinimas",
        "neviltis",
        "atsipalaidavęs",
        "beviltiška",
        "niekingas",
        "NO TRANSLATION",
        "despotiškas",
        "despotiškumas",
        "destitute",
        "sunaikinta",
        "sunaikintojas",
        "sunaikinti",
        "sunaikinimas",
        "destruktyvus",
        "atskyrimas",
        "sulaikyti",
        "sulaikytasis",
        "sulaikymas",
        "pablogėja",
        "pablogėjo",
        "pablogėjimas",
        "gėda",
        "detonuoti",
        "atmesti",
        "žala",
        "žalingas",
        "detritus",
        "sunaikinti",
        "niokojantis",
        "nuniokojimas",
        "velnias",
        "velnias",
        "klaidingas",
        "devoliucija",
        "valgyk",
        "velniškas",
        "diagnozė",
        "Diatribe",
        "diktatorius",
        "diktatūrinis",
        "diktatūra",
        "NO TRANSLATION",
        "sunkumai",
        "sunku",
        "nukrypti",
        "nykstantis",
        "atskiesti",
        "mažėja",
        "sumažėjo",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "purvas",
        "purvinas",
        "negalia",
        "išjungti",
        "išjungtas",
        "nepasitenkinimas",
        "nesutikti",
        "nesutinku",
        "nesutarimas",
        "neleidžiama",
        "nuvilti",
        "nusivylusi",
        "nusivylęs",
        "nusivylimas",
        "nepatvirtinimas",
        "nepatvirtinkite",
        "nepatvirtintas",
        "nepatvirtinti",
        "nelaimė",
        "katastrofiškas",
        "netikėti",
        "išmetimas",
        "išleidimas",
        "disciplina",
        "atsisakyti",
        "spalvos pasikeitimas",
        "pasikeitė",
        "diskomfortas",
        "atjunkite",
        "atjungtas",
        "atjungimas",
        "nepasitenkinimas",
        "nutraukti",
        "nutraukimas",
        "nesantaika",
        "atgrasinkite",
        "nusivylimas",
        "diskredituoti",
        "diskriminuoti",
        "diskriminuojantis",
        "diskriminacija",
        "nusivylimas",
        "liga",
        "sergantis",
        "neprilygstamas",
        "atmetimas",
        "iškraipyta",
        "gėda",
        "NO TRANSLATION",
        "gėdingas",
        "nepatogus",
        "pasibjaurėjimas",
        "bjaurus",
        "nerimtas",
        "disheartening",
        "nesąžiningas",
        "nesąžiningumas",
        "nesąžiningi",
        "nusivylimas",
        "dezinformacija",
        "menkas",
        "suskaidyti",
        "suskaidymas",
        "nesuinteresuotas",
        "nepatinka",
        "nepatinka",
        "dislokuotas",
        "žiaurus",
        "sumišimas",
        "suskaidymas",
        "atleidimas iš darbo",
        "nepaklusnumas",
        "nepaklusnus",
        "nepaklusti",
        "sutrikimas",
        "netvarkingai",
        "neorganizuotas",
        "nusiminusi",
        "nusivylimas",
        "skirtumas",
        "beviltiška",
        "išsklaidyti",
        "dispersija",
        "išstumti",
        "nepatinka",
        "nepatenkinti",
        "šalinimas",
        "išlaisvinta",
        "gintis",
        "diskvalifikacija",
        "diskvalifikuotas",
        "diskvalifikuoti",
        "nepaisyti",
        "neatsižvelgiama",
        "nepriimtinas",
        "nepagarba",
        "nepagarbus",
        "žlugimas",
        "nepasitenkinimas",
        "nesantaika",
        "nepasitenkinimas",
        "kantrumas",
        "disidentas",
        "tirpimas",
        "disonansas",
        "atsikratyti",
        "nepatogus",
        "iškreipta",
        "iškraipymas",
        "atitraukti",
        "išsiblaškęs",
        "blaško",
        "išsiblaškymas",
        "iškraipytas",
        "nelaimė",
        "susikrimtęs",
        "kankinantis",
        "nepasitikėjimas",
        "trikdymas",
        "sutrikdyta",
        "išnaudoti",
        "išnaudotas",
        "skiriasi",
        "parduotas",
        "atskyrimas",
        "skyrybos",
        "galvos svaigimas",
        "apsvaigęs",
        "prijungtas",
        "NO TRANSLATION",
        "silpnumas",
        "Dole",
        "NO TRANSLATION",
        "dominuojantis",
        "dominavimas",
        "asilas",
        "Doodle",
        "lemtis",
        "pasmerktas",
        "pasimatymų diena",
        "abejonių",
        "abejotinas",
        "abejotinas",
        "dušas",
        "saldus",
        "žlugimas",
        "drab",
        "drenažas",
        "trūkumas",
        "baimė",
        "baisus",
        "baisiai",
        "nuobodus",
        "gerti",
        "Drivel",
        "drone",
        "nusileidimas",
        "sausra",
        "nuskęsti",
        "mieguistumas",
        "drudgery",
        "girtas",
        "girtavimas",
        "abejotinas",
        "nuobodus",
        "kvailas",
        "manekenas",
        "sąvartynai",
        "dun",
        "Dungeon",
        "dupe",
        "dvilypumas",
        "priversti",
        "dulkes",
        "nykštukas",
        "mirti",
        "dizenterija",
        "žemės drebėjimas",
        "slapyvardis",
        "Edict",
        "moteriški",
        "egoistinis",
        "kankinantis",
        "išmesti",
        "išmetimas",
        "pašalinimas",
        "nepakankamas",
        "išnykęs",
        "NO TRANSLATION",
        "nuliūdinti",
        "nepatogus",
        "sumišimas",
        "grobstymas",
        "embolija",
        "įstrigo",
        "Skubus atvėjis",
        "anklavą",
        "įsibrovimas",
        "apkrovimas",
        "kelti grėsmę",
        "nykstantis",
        "endemiškas",
        "priešas",
        "vykdymas",
        "paslaptinga",
        "priešiškumas",
        "pavergti",
        "pavergė",
        "pavergimas",
        "įsipainiojęs",
        "įsipainiojimas",
        "angarai",
        "pavydus",
        "epidemija",
        "epilepsija",
        "išnaikinti",
        "likvidavimas",
        "ištrinti",
        "erozija",
        "klaida",
        "klaidinga",
        "nepastovus",
        "Erratum",
        "klaidingas",
        "klaida",
        "išsiveržti",
        "išsiveržimas",
        "išsiplėsti",
        "išvengti",
        "šnipinėjimas",
        "šalinasi",
        "eutanazija",
        "evakuoti",
        "evakuacija",
        "išvengti",
        "vengimas",
        "iškeldinti",
        "iškeldinimas",
        "velnias",
        "sustiprinti",
        "paūmėjimas",
        "griežtas",
        "perdėti",
        "perdėtas",
        "egzaminas",
        "pasipiktinimas",
        "kasimas",
        "perviršis",
        "akcizas",
        "neįtraukta",
        "išskyrus",
        "išskyrimas",
        "ekskrementai",
        "siaubingas",
        "atleiskite",
        "vykdymas",
        "kareivis",
        "išmetimas",
        "išnaudota",
        "išsekimas",
        "NO TRANSLATION",
        "tremtis",
        "eksorcizmas",
        "išvykti iš šalies",
        "išsiųsti",
        "išlaidos",
        "išlaidos",
        "pasibaigia",
        "pasibaigė",
        "pagarbus",
        "sprogti",
        "sprogimas",
        "sprogi",
        "eksponuotos",
        "nusavinimas",
        "išsiuntimas iš šalies",
        "naikinti",
        "naikinimas",
        "išnykęs",
        "gesinti",
        "neteisminis",
        "galūnės",
        "pagaminti",
        "gamyba",
        "išnyks",
        "išmatos",
        "nesėkmingai",
        "nesėkmė",
        "alpulys",
        "tikintis",
        "netikrą",
        "kritimo",
        "klaidingas",
        "klaida",
        "klaidingas",
        "kritimas",
        "padeti",
        "melas",
        "klaidingai",
        "falsifikavimas",
        "klastoti",
        "neteisingumas",
        "plakti",
        "badas",
        "fanatikas",
        "farsas",
        "farcical",
        "badas",
        "riebalai",
        "mirtinas",
        "mirtis",
        "likimas",
        "nuovargis",
        "pavargęs",
        "riebalingas",
        "kaltė",
        "klaidingas",
        "žvilgsnis",
        "baimė",
        "baisu",
        "baisiai",
        "bijodamas",
        "karščiavimas",
        "išmatuota",
        "išmatos",
        "rinkliava",
        "silpnas",
        "įžeistas",
        "nukrito",
        "Felonas",
        "nusikaltimas",
        "fermentas",
        "žiaurus",
        "žiaurumas",
        "feudas",
        "feodalinė",
        "feodalizmas",
        "karščiavimas",
        "fiasko",
        "plikas",
        "nepastovus",
        "fiktyvus",
        "velnias",
        "aštri",
        "kovoti",
        "kovos",
        "filibuster",
        "purvinas",
        "purvinas",
        "šaunamieji ginklai",
        "tinka",
        "įtemptas",
        "švelnus",
        "žymėjimas",
        "akivaizdus",
        "sluoksnis",
        "atvartas",
        "meteorizmas",
        "pasigrožėti",
        "trūkumas",
        "blusas",
        "NO TRANSLATION",
        "vilna",
        "mėsingas",
        "šnibždėti",
        "flogas",
        "flop",
        "plekšnė",
        "gripas",
        "svyravimai",
        "priešas",
        "sugadintas",
        "kvailystė",
        "kvailys",
        "kvaila",
        "kvailystė",
        "pašaras",
        "atvykti",
        "uždrausti",
        "draudžiama",
        "jėga",
        "priverstas",
        "prievarta",
        "foreboding",
        "uždaryti",
        "atleiskite",
        "užsienio",
        "užsienietis",
        "įsitikinęs",
        "prarasti",
        "prarastas",
        "konfiskavimas",
        "klastojimas",
        "pamiršk",
        "pamiršta",
        "forlorn",
        "beformus",
        "brolija",
        "palikti",
        "paliktas",
        "negerai",
        "lūžis",
        "trapi",
        "silpnumas",
        "beviltiška",
        "sukčiavimas",
        "apgavikiškas",
        "kupinas",
        "pasipriešinimas",
        "sugadintas",
        "keista",
        "užšaldymas",
        "bjaurus",
        "siaubingas",
        "beprotybė",
        "nerimas",
        "baimė",
        "bijoti",
        "išgąsdinti",
        "baisus",
        "drąsus",
        "lengvas",
        "apsaldymas",
        "putos",
        "druska",
        "nemalonus",
        "bevaisis",
        "iškraipyti",
        "nusivylęs",
        "nusivylimas",
        "apgaulė",
        "bėgikas",
        "garbinti",
        "dūmai",
        "dumbliai",
        "grybelis",
        "funk",
        "įsiutę",
        "furoras",
        "įniršis",
        "šurmulys",
        "baisus",
        "beprasmiška",
        "beviltiškumas",
        "gaby",
        "gag",
        "tulžis",
        "šiaudai",
        "lošti",
        "lošėjas",
        "azartiniai lošimai",
        "gauja",
        "gaol",
        "atotrūkis",
        "šiukšlių",
        "garish",
        "garnyras",
        "gashas",
        "džiūstantys",
        "NO TRANSLATION",
        "gaudyti",
        "Gent",
        "geriatric",
        "šlykštus",
        "getas",
        "vaiduoklis",
        "gibberis",
        "ledinis",
        "atspindys",
        "akivaizdu",
        "glib",
        "drumstis",
        "niūri",
        "glum",
        "perpylimas",
        "blyškumas",
        "gnome",
        "Goblinas",
        "bedievis",
        "gonorėja",
        "goo",
        "įsiuvas",
        "Gorge",
        "gorila",
        "gory",
        "paskalos",
        "gouge",
        "podagra",
        "vyriausybė",
        "patraukti",
        "gaudyti",
        "grotelės",
        "tarkuotas",
        "groteles",
        "kapas",
        "godumas",
        "godus",
        "granatas",
        "sielvartas",
        "skundas",
        "sielvartas",
        "sunkus",
        "siauras",
        "grime",
        "nuobodus",
        "šlifavimas",
        "siaubingai",
        "grizzly",
        "groan",
        "NO TRANSLATION",
        "bruto",
        "groteskas",
        "pagrįstas",
        "nepagrįstas",
        "Groti",
        "Groti",
        "apgailestauti",
        "negailestingai",
        "baisus",
        "gruobas",
        "šoktelėti",
        "bjaurus",
        "karalius",
        "gailestis",
        "giljotina",
        "kaltumas",
        "kaltas",
        "išvaizda",
        "kepuraitė",
        "patikimos",
        "ginklas",
        "gush",
        "garsas",
        "čigonai",
        "kaklelis",
        "pasipūtęs",
        "plaukuotas",
        "pusiaukelėje",
        "haliucinacijos",
        "apleista",
        "sustabdymas",
        "trukdyti",
        "hamstringas",
        "negalia",
        "kabantis",
        "pakabinkis",
        "priekabiauti",
        "prancūzas",
        "grūdintas",
        "kietumas",
        "sunkumas",
        "brolija",
        "žala",
        "kenksmingas",
        "siaubti",
        "Harry",
        "kietumas",
        "hash",
        "Hasisas",
        "skubotas",
        "nekenčiu",
        "žiaurus",
        "nekenčiu",
        "neapykanta",
        "sąmojingas",
        "vaidentis",
        "apsėstas",
        "žlugimas",
        "pavojus",
        "pavojingas",
        "migla",
        "galvos skausmas",
        "bjaurus",
        "klausymasis",
        "garsiai",
        "Kasetė",
        "sielvartas",
        "rėmuo",
        "beprasmiškas",
        "pagonys",
        "stipriai",
        "kulnas",
        "pakelti",
        "griovus",
        "pragaras",
        "pragaras",
        "bejėgis",
        "bejėgiškumas",
        "kraujavimas",
        "hemorojus",
        "erezija",
        "eretikas",
        "hermaphroditas",
        "heroinas",
        "herpesas",
        "herpes virusas",
        "dvejonės",
        "paslėpta",
        "kvailas",
        "trukdo",
        "trukdymas",
        "hipis",
        "šypsotis",
        "šnibždantis",
        "nukentėti",
        "iki šiol",
        "avilys",
        "siauras",
        "siauras",
        "apgaulė",
        "HBO",
        "šernas",
        "tuščiaviduris",
        "holokaustas",
        "benamiai",
        "pasimatymas",
        "žmogžudys",
        "žmogžudystė",
        "homoseksualumas",
        "gaubtas",
        "užsikabinęs",
        "Hoot",
        "beviltiška",
        "beviltiškumas",
        "orda",
        "siaubingas",
        "siaubingai",
        "siaubingas",
        "siaubingas",
        "siaubu",
        "siaubingas",
        "siaubas",
        "siaubo",
        "įkaitas",
        "priešiškas",
        "karo veiksmai",
        "priešiškumas",
        "gaudyti",
        "Huff",
        "Humbug",
        "pažeminti",
        "žeminantis",
        "pažeminimas",
        "kvailys",
        "alkanas",
        "medžiotojas",
        "medžioklė",
        "uraganas",
        "skubėti",
        "skauda",
        "žalingas",
        "skauda",
        "Hustler",
        "Hidra",
        "hidrocefalija",
        "hype",
        "hiperbolė",
        "veidmainystė",
        "veidmainas",
        "veidmainiškas",
        "isterija",
        "isteriškas",
        "idiotiškumas",
        "idiotas",
        "idiotiškas",
        "tuštybė",
        "stabmeldystė",
        "nežinojimas",
        "neišmanantis",
        "ignoruoti",
        "nesveikas",
        "neteisėtas",
        "neteisėtumas",
        "neįskaitomas",
        "neteisėtas",
        "neteisėtas",
        "neraštingas",
        "liga",
        "nelogiška",
        "iliuzija",
        "imituotas",
        "imitacija",
        "nesubrendęs",
        "nebrandumas",
        "amoralus",
        "amoralumas",
        "pabloginti",
        "sumažėjimas",
        "nepertraukiamas",
        "nekantrumas",
        "nekantrus",
        "impeach",
        "apkaltos",
        "trukdyti",
        "netobulumas",
        "netobula",
        "apsimesti",
        "apsimetinėjimas",
        "nepagrįstas",
        "prisiminti",
        "nepagarbus",
        "įvedimas",
        "neįmanomas",
        "impotencija",
        "bejėgis",
        "prisiminti",
        "neįmanoma",
        "įkalinimas",
        "įkalintas",
        "laisvės atėmimas",
        "netinkamumas",
        "neprotingas",
        "nešvarus",
        "priemaiša",
        "priskyrimas",
        "nesugebėjimas",
        "neprieinama",
        "netikslus",
        "neveikimas",
        "neveiklumas",
        "NO TRANSLATION",
        "nepakankamas",
        "nepriimtinas",
        "neribotas",
        "netaikytina",
        "netinkamas",
        "neatsargumas",
        "neskausmingas",
        "neįkainojamas",
        "nedarbingumas",
        "įkalinimas",
        "tuo atveju",
        "uždegiminis",
        "smilkalai",
        "tęstinis",
        "incestas",
        "infekcinė",
        "deginimas",
        "paskatinti",
        "nelygus",
        "nesuderintas",
        "nesuderinama",
        "nekompetencija",
        "nekompetentingas",
        "neišsamumas",
        "nesuprantama",
        "netinkamas",
        "nesvarbus",
        "nesvarbu",
        "nenuoseklumas",
        "nepatogu",
        "neteisingas",
        "neatitikus",
        "kaltinimas",
        "inkubas",
        "patirti",
        "neišgydomas",
        "įsiveržimas",
        "nepadorus",
        "nelygybė",
        "neryžtingas",
        "nepagrįstas",
        "atlyginti žalą",
        "indenture",
        "neapibrėžtas",
        "kaltinamasis",
        "kaltinamoji akcija",
        "abejingumas",
        "neturtingas",
        "pasipiktinęs",
        "pasipiktinimas",
        "neaiškus",
        "indoktrinacija",
        "indolent",
        "neefektyvus",
        "neefektyvus",
        "neveiksmingumas",
        "neefektyvus",
        "negerai",
        "netinkamumas",
        "nelygybė",
        "neteisinga",
        "inertiška",
        "nepateisinamas",
        "NO TRANSLATION",
        "nepatyręs",
        "nepaaiškinamas",
        "liūdnai",
        "skriaudimas",
        "kūdikiams",
        "kūdikiškas",
        "infarktas",
        "užkrėsti",
        "infekcija",
        "infekcinis",
        "prastesnė",
        "nepilnavertiškumas",
        "inferno",
        "nevaisingumas",
        "užkrėtimo",
        "neteisingas",
        "netikėjimas",
        "silpnas",
        "silpnumas",
        "uždegimas",
        "pripūstos",
        "infliacija",
        "sukelti",
        "priespauda",
        "gripas",
        "informatorius",
        "pažeidimas",
        "retai",
        "pažeidimas",
        "slopinti",
        "nešiotis",
        "nežmoniškas",
        "nežmoniškumas",
        "neigiamas",
        "neteisybė",
        "įsakymas",
        "sužeisti",
        "sužeistas",
        "žalingas",
        "sužalojimas",
        "neteisinga",
        "kalinys",
        "neveikia",
        "psichiškas",
        "beprotybė",
        "nesaugu",
        "nesaugumas",
        "klastingas",
        "nereikšmingumas",
        "nereikšmingas",
        "įsišaknijęs",
        "įžūlus",
        "nemokumas",
        "nemokus",
        "nestabilumas",
        "paskatinti",
        "kurstymas",
        "nepakankamumas",
        "nepakankamas",
        "nepakankamai",
        "įžeidimas",
        "įžeidimas",
        "maištininkas",
        "neįveikiama",
        "sukilimas",
        "inter",
        "uždraudimas",
        "trikdymas",
        "siela",
        "nutraukti",
        "nutrauktas",
        "Neteisingas",
        "įbauginti",
        "bauginimas",
        "nepakeliamas",
        "netolerancija",
        "netoleranti",
        "apsvaigęs",
        "nesuderinamas",
        "intrigos",
        "įsibrovėlis",
        "įsibrovimas",
        "intrusyvus",
        "įsiveržti",
        "įsibrovėlis",
        "negaliojantis",
        "negaliojimas",
        "invalidumas",
        "invazija",
        "Neprivalomas",
        "involiucija",
        "irate",
        "NO TRANSLATION",
        "lygintuvai",
        "neracionalus",
        "neracionalumas",
        "nesuderinamas",
        "netaisyklingas",
        "pažeidimas",
        "nesvarbu",
        "nepataisoma",
        "neatsakingas",
        "nepagarbus",
        "neatšaukiamas",
        "dirglumas",
        "irzlus",
        "dirgina",
        "dirginimas",
        "izoliuotas",
        "izoliacija",
        "jabber",
        "kalėjimas",
        "žargonas",
        "Jarring",
        "gelta",
        "pavydus",
        "pavydas",
        "pavojaus",
        "pavojus",
        "Jonas",
        "pokštas",
        "NO TRANSLATION",
        "sumušti",
        "šiukšlių",
        "hunta",
        "nepilnametis",
        "kern",
        "smūgis",
        "pagrobti",
        "nužudyti",
        "žudymas",
        "aitvaras",
        "knell",
        "sujungtas",
        "dirbo",
        "sunkus darbas",
        "labirintas",
        "trūksta",
        "trūksta",
        "neryškus",
        "pakrauta",
        "atsilikimas",
        "atsilieka",
        "lair",
        "gailestis",
        "nuošliaužos",
        "tingus",
        "nykti",
        "nuoga",
        "pasibaigia",
        "larceny",
        "blakstiena",
        "vėlai",
        "vėlavimas",
        "latentinis",
        "lentynos",
        "juokiasi",
        "lava",
        "neteisybė",
        "ieškinys",
        "teisininkas",
        "lax",
        "vidurius",
        "tingus",
        "nutekėti",
        "nuotėkis",
        "nutekėjusi",
        "palikti",
        "sode",
        "rausvai",
        "NO TRANSLATION",
        "citrina",
        "raupsai",
        "lesbiečių",
        "sumažinti",
        "mažesnis",
        "mirtina",
        "mieguistumas",
        "leukemija",
        "rinkliava",
        "bjaurus",
        "ryšys",
        "melagis",
        "klibėti",
        "laižyti",
        "melas",
        "negyvas",
        "ribotas",
        "švelnus",
        "geltona",
        "likeris",
        "nesvarbu",
        "ginčas",
        "ginčyti bylą",
        "bylinėjimasis",
        "ginčytinas",
        "pakratai",
        "gyvas",
        "kepalas",
        "slapyvardis",
        "NO TRANSLATION",
        "nepastebimas",
        "apgailėtinas",
        "apgailėtinas",
        "lobistas",
        "NO TRANSLATION",
        "saldainis",
        "aukštasis",
        "vienatvė",
        "vienišas",
        "vienišas",
        "loo",
        "stelažai",
        "Loon",
        "kvailas",
        "loterija",
        "prarasti",
        "praranda",
        "nuostolis",
        "prarastas",
        "garsumas",
        "holas",
        "garsas",
        "mažesnis",
        "nuleisti",
        "Žemiausia",
        "žemumos",
        "žemas",
        "juokinga",
        "lumbering",
        "vienkartinis",
        "vienkartinis",
        "nepaklusnumas",
        "nemalonus",
        "Lurch",
        "privilioti",
        "purvinas",
        "pasislėpk",
        "pasislėpęs",
        "sodrus",
        "geismas",
        "liūdnas",
        "melas",
        "lynch",
        "mace",
        "piktas",
        "maddenas",
        "beprotis",
        "beprotybė",
        "mafija",
        "burbulas",
        "laikinasis",
        "blogis",
        "negalavimas",
        "maliarija",
        "piktas",
        "piktnaudžiavimas",
        "anomalija",
        "piktybė",
        "kenksminga",
        "kenksmingas",
        "piktybiniai navikai",
        "piktybinis",
        "piktnaudžiavimas",
        "mandamus",
        "NO TRANSLATION",
        "mangle",
        "manija",
        "maniakas",
        "maniakinis",
        "manipuliuoti",
        "manipuliavimas",
        "žmogžudystė",
        "mėšlas",
        "maras",
        "marža",
        "maroon",
        "martingale",
        "kankinys",
        "kankinys",
        "masochizmas",
        "žudynes",
        "materializmas",
        "materialistinis",
        "bjaurus",
        "beprasmis",
        "tymai",
        "įsibraukti",
        "vidutiniškas",
        "vidutiniškumas",
        "melancholinis",
        "melancholija",
        "melee",
        "melodrama",
        "Meltdown",
        "Gresmė",
        "grėsmingas",
        "menial",
        "samdinys",
        "negailestingas",
        "netvarka",
        "netinkamas",
        "metastazė",
        "metanolis",
        "miltligė",
        "milicija",
        "mimicry",
        "sumažinti iki minimumo",
        "minimumas",
        "mažuma",
        "NO TRANSLATION",
        "neteisingas elgesys",
        "persileidimas",
        "pyktis",
        "bjaurus",
        "klaidingas supratimas",
        "nusižengimas",
        "apgailėtinas",
        "apgailėtinai",
        "nelaimė",
        "nelaimė",
        "klaidingas",
        "nesėkmė",
        "neteisingas supratimas",
        "klaidinti",
        "klaidinantis",
        "netinkamas valdymas",
        "neatitikimas",
        "klaidingas vardas",
        "klaidinga vieta",
        "netinkamas",
        "klaidinga informacija",
        "klaidinga informacija",
        "klaidingai pateikta",
        "dingęs",
        "iškraipymas",
        "klaida",
        "klaidinga",
        "šeimininkė",
        "NO TRANSLATION",
        "neteisingai supratau",
        "nesusipratimas",
        "piktnaudžiavimas",
        "erkė",
        "mob",
        "pasityčiojimas",
        "išminkimas",
        "tvirkinimas",
        "monochrominis",
        "monopolistas",
        "musonas",
        "monstras",
        "monstrosity",
        "paniuręs",
        "tvirtas",
        "blogas",
        "sergamumas",
        "Morgas",
        "miršta",
        "Kvailys",
        "moroninis",
        "kumpis",
        "mirtingasis",
        "mirtingumas",
        "sunaikinimas",
        "mortuaras",
        "uodai",
        "gedėti",
        "gedulingas",
        "gedulas",
        "muck",
        "purvas",
        "supainioti",
        "sumaišytas",
        "purvinas",
        "mufas",
        "muulas",
        "mama",
        "mumble",
        "kiaulytė",
        "nužudymas",
        "žudikas",
        "nužudantis",
        "siauras",
        "NO TRANSLATION",
        "purvinas",
        "mutantas",
        "sugadintas",
        "žalojimas",
        "maištas",
        "NO TRANSLATION",
        "snukis",
        "trumparegystė",
        "nab",
        "nadir",
        "NO TRANSLATION",
        "naivus",
        "bevardis",
        "vystyklai",
        "narkotinis",
        "bjaurus",
        "neklaužada",
        "pykinimas",
        "niežulys",
        "NO TRANSLATION",
        "reikalingas",
        "vargšas",
        "blogas",
        "negacija",
        "neigiamas",
        "nepaisyti",
        "nepastebėta",
        "nepaisant",
        "aplaidumas",
        "aplaidumas",
        "NO TRANSLATION",
        "negra",
        "nepotizmas",
        "nervingas",
        "netgi",
        "dilgėlė",
        "neuralgija",
        "neurozė",
        "neurotiškas",
        "nikotinas",
        "nigger",
        "košmaras",
        "nihilizmas",
        "triukšmas",
        "triukšmingas",
        "NO TRANSLATION",
        "nesąmonė",
        "absurdiškas",
        "kanalas",
        "nieko",
        "kenksmingas",
        "nemalonumas",
        "NO TRANSLATION",
        "atšaukti",
        "numb",
        "tirpimas",
        "NO TRANSLATION",
        "oafas",
        "nutukusi",
        "nutukimas",
        "obi",
        "obit",
        "netikras",
        "prieštaravimas",
        "nepagrįstas",
        "įpareigoti",
        "įsipareigojantis asmuo",
        "sunaikinti",
        "sunaikinta",
        "obliteracija",
        "užmarštis",
        "nemalonus",
        "nepadorus",
        "nešvankumas",
        "nežinomybė",
        "kliūtis",
        "užsispyręs",
        "trukdyti",
        "obstrukcija",
        "obstrukcinis",
        "bukas",
        "okultas",
        "keista",
        "bjaurus",
        "kvapas",
        "įžeisti",
        "įžeistas",
        "nusikaltėlis",
        "nusikaltimas",
        "agresyvus",
        "išjungtas",
        "išsiveržimas",
        "Oglė",
        "uoslės",
        "oligarchija",
        "pranašai",
        "žiaurus",
        "praleisti",
        "apsunkintas",
        "onus",
        "šilti",
        "nepermatomas",
        "opera",
        "Opiat",
        "patyręs",
        "opiumas",
        "priešininkas",
        "priešintis",
        "priešinosi",
        "opozicija",
        "prispausti",
        "priespauda",
        "slegiantis",
        "prispaudėjas",
        "orc",
        "išbandymas",
        "amunicija",
        "našlaitis",
        "tariamai",
        "išstumti",
        "apleistas",
        "protestas",
        "lauko namai",
        "svetimas",
        "neteisėta",
        "pasipiktinimas",
        "ovacija",
        "valdomas",
        "perkrautas",
        "per naktį",
        "persidaryti",
        "perdozavimas",
        "pavėluotas",
        "pervertintas",
        "perpildymas",
        "užaugo",
        "perkrovos",
        "permokėta",
        "pralenkti",
        "pergalingas",
        "pervertintas",
        "priežiūra",
        "nuversti",
        "apeiti",
        "priblokšti",
        "priblokštas",
        "dėl to",
        "oksidacija",
        "skausmas",
        "kankina",
        "skausmingas",
        "skausmingai",
        "skausmai",
        "paralyžius",
        "pandemija",
        "NO TRANSLATION",
        "panika",
        "paralyžius",
        "paralyžiuotas",
        "paranoja",
        "parazitas",
        "NO TRANSLATION",
        "papūga",
        "parsimonious",
        "partizaninis",
        "NO TRANSLATION",
        "pasyvus",
        "pasyvumas",
        "pleistras",
        "apgailėtina",
        "globoja",
        "NO TRANSLATION",
        "mažumas",
        "pauper",
        "pėstininkas",
        "atsipirkimas",
        "mokėjimas",
        "ypatumai",
        "pėsčiųjų",
        "baudžiamoji",
        "bausmė",
        "įsiskverbimas",
        "kalinimo įstaiga",
        "žudymas",
        "pavojus",
        "pavojingas",
        "prarasti",
        "greitai gendantis",
        "žuvo",
        "žūva",
        "liudinėjimas",
        "žalingas",
        "kaltininkas",
        "išlaikymas",
        "suglumęs",
        "sumišimas",
        "persekioti",
        "persekiojimas",
        "pasipiktinimas",
        "kokliušo",
        "kvailas",
        "perversimas",
        "iškrypėlis",
        "iškraipytas",
        "pesimizmas",
        "pesimistas",
        "kenkėjas",
        "maras",
        "naminis gyvūnėlis",
        "mažas",
        "fantomas",
        "skreplius",
        "apgavikas",
        "piketas",
        "piketavimas",
        "marinuoti",
        "kiaulė",
        "balandis",
        "poliai",
        "plėšimas",
        "Pušis",
        "spuogas",
        "pušis",
        "krumpliaratis",
        "pykis",
        "piratavimas",
        "piratas",
        "pistoletas",
        "pataikymas",
        "plagiatas",
        "maras",
        "ieškovas",
        "padengtas",
        "žaidėjas",
        "pagrindas",
        "sunku",
        "plodding",
        "svyruoja",
        "grobtis",
        "pasinerti",
        "pneumonija",
        "brakonieriavimas",
        "beprasmiškas",
        "nuodai",
        "apsinuodijęs",
        "apsinuodijimas",
        "nuodingas",
        "mocać",
        "polemika",
        "poliomielitas",
        "teršia",
        "tarša",
        "poligamija",
        "pomp",
        "pompuotas",
        "sunkus",
        "blogai",
        "popas",
        "porcupine",
        "porno",
        "porno",
        "pornografinis",
        "pornografija",
        "kelti",
        "turima",
        "valdymas",
        "postuomas",
        "atidėjimas",
        "svaras",
        "skurdas",
        "bejėgis",
        "pritrenkti",
        "nestabili",
        "sklypas",
        "grobuoniškas",
        "sunkumų",
        "nėštumas",
        "prietarai",
        "įžeidė",
        "žalingas",
        "apgalvota",
        "spaudimas",
        "įžūlus",
        "apsimesti",
        "apsimeta",
        "apsimeta",
        "pretenzija",
        "pretenzijos",
        "prevencinis",
        "grobis",
        "traukti",
        "dygliuotas",
        "kalėjimas",
        "kalinys",
        "paslaptis",
        "problema",
        "atidėti",
        "vilkinimas",
        "apgaulingas",
        "neteisybė",
        "gausa",
        "draudžiama",
        "draudimas",
        "prailginti",
        "promiscuous",
        "propaganda",
        "baudžiamasis persekiojimas",
        "baudžiamasis persekiojimas",
        "prostitute",
        "prostitucija",
        "provokacija",
        "provokuojantis",
        "pry",
        "smalsus",
        "psichozė",
        "publicistas",
        "pūlingas",
        "Punch",
        "aštrus",
        "nubausti",
        "nubaustas",
        "bausti",
        "bausmė",
        "baudžiamoji",
        "grynintuvas",
        "valyti",
        "pusė",
        "kvailys",
        "dviratininkas",
        "pledai",
        "kvailystė",
        "ginčytis",
        "nulaužti",
        "paklusti",
        "abejotinas",
        "geltona žaliava",
        "mesti",
        "strėlinė",
        "drebulys",
        "viktorina",
        "siaubas",
        "bjaurus",
        "pasiutligė",
        "stovas",
        "raketė",
        "radiacija",
        "radioaktyvusis",
        "radonas",
        "pyktis",
        "siaubti",
        "skudurus",
        "reidas",
        "geležinkeliu",
        "ram",
        "rambling",
        "rampa",
        "riebi",
        "išpirkti",
        "išžaginimas",
        "raptorius",
        "sunkus",
        "bėrimas",
        "žiurkė",
        "įvertinimas",
        "rausvas",
        "rausvas",
        "ravingas",
        "reakcinis",
        "galas",
        "sukilėlių",
        "sunaikinti",
        "paneigti",
        "nepaklusnus",
        "nuosmukis",
        "recidyvizmas",
        "neapgalvota",
        "neapdairumas",
        "nereikalingas",
        "refliuksas",
        "ugniai atsparus",
        "atsisakymas",
        "atsisakyti",
        "atsisakyta",
        "regresas",
        "regresija",
        "apgailestauju",
        "apgailestauja",
        "apgailestauja",
        "apgailestauju",
        "reguliavimo",
        "pervesti",
        "atmesti",
        "Atstumtas",
        "atmetimas",
        "atmeta",
        "atkrytis",
        "iškritimas",
        "atsisakyti",
        "nenoriai",
        "suėmimas",
        "taisomasis",
        "atleidimas",
        "gailestis",
        "pašalinimas",
        "pašalinti",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "Renegade",
        "atsisakyti",
        "atsisakymas",
        "NO TRANSLATION",
        "atstumiantis",
        "atstumiantis",
        "sunaikinti",
        "represijos",
        "papeikimas",
        "išpardavimas",
        "represija",
        "priekabiavimas",
        "respublika",
        "atsisakymas",
        "atbaidymas",
        "atšaukti",
        "atšaukimas",
        "pasipiktinęs",
        "įsižeidęs",
        "apmaudas",
        "pasitraukti",
        "atsistatydinimas",
        "atsistatydino",
        "pasipriešinti",
        "pasipriešinimas",
        "atsparus",
        "atsparus",
        "sulaikyti",
        "apriboti",
        "apribojimas",
        "ribojantis",
        "atsakomoji priemonė",
        "kerštas",
        "atsakomoji priemonė",
        "retard",
        "lėtinimas",
        "reticent",
        "retort",
        "atsitraukti",
        "atšaukimas",
        "sumažinimas",
        "atlyginimas",
        "atgaline data",
        "kerštas",
        "pasikeitimas",
        "atšaukimas",
        "atšaukti",
        "sukilimas",
        "maištingas",
        "revolveris",
        "pasipiktinimas",
        "reumatas",
        "baisus",
        "raižyti",
        "juoktis",
        "juokinga",
        "rife",
        "šautuvas",
        "riftas",
        "standus",
        "standumas",
        "griežtumas",
        "griežtas",
        "skambutis",
        "riaušės",
        "neramus",
        "rizika",
        "rizikingas",
        "varžymasis",
        "apiplėšti",
        "plėšikas",
        "apiplėšimas",
        "nesąžiningi",
        "rook",
        "puvėti",
        "puvimas",
        "šiurkštumas",
        "NO TRANSLATION",
        "eilutė",
        "bjaurus",
        "šiukšlės",
        "griuvėsiai",
        "rue",
        "ruffle",
        "tvirtas",
        "sugadinti",
        "sugadintas",
        "griovus",
        "gandas",
        "pabėgti",
        "plyšimas",
        "NO TRANSLATION",
        "rūdys",
        "rusvas",
        "negailestingas",
        "NO TRANSLATION",
        "sabotažas",
        "aukos",
        "deja",
        "liūdesys",
        "sag",
        "sap",
        "sarkazmas",
        "sarkoma",
        "Sardonikas",
        "sataniškas",
        "prisotintas",
        "laukinis",
        "žiaurumas",
        "šašas",
        "pastoliai",
        "skalpelis",
        "žvynuotas",
        "skandalas",
        "skandalingas",
        "menkas",
        "atpirkimo atlygis",
        "randas",
        "trūksta",
        "vargu ar",
        "trūkumas",
        "panika",
        "prievartautojas",
        "schema",
        "schizma",
        "šizofrenija",
        "išialgija",
        "siautėti",
        "šmeižti",
        "sumušimas",
        "karštas",
        "nusivylimas",
        "skorpionas",
        "scotch",
        "nesąmonė",
        "rykštė",
        "sumušimas",
        "skrepi",
        "šaukti",
        "rėkia",
        "šaukti",
        "prisukamas",
        "kareivis",
        "šveitimas",
        "atidžiai patikrink",
        "tikrinimas",
        "riebalai",
        "kirzas",
        "atsiskyrimas",
        "atskirai",
        "NO TRANSLATION",
        "sekrecija",
        "slaptasis",
        "sektaniškas",
        "sukilimas",
        "suvilioti",
        "gundymas",
        "atskirti",
        "atskiriamas",
        "pasinaudoti",
        "savanaudis",
        "savanaudiškumas",
        "seniulis",
        "beprasmis",
        "sakinys",
        "separatistinis",
        "sepsis",
        "septinis",
        "sekvestracija",
        "ramus",
        "gyvatė",
        "tarnas",
        "tarnauti",
        "servile",
        "servitutas",
        "pasipriešinimas",
        "nutraukti",
        "nuotekos",
        "kanalizacija",
        "apdriskęs",
        "kratinys",
        "sijonas",
        "šešėliai",
        "drebėjimas",
        "drebantis",
        "plaktukas",
        "sunaikinti",
        "gėda",
        "gėdingas",
        "be nieko",
        "Šanchajus",
        "ryklys",
        "suplakti",
        "susmulkintas",
        "shed",
        "apvalkalas",
        "lentyna",
        "laivo avarija",
        "šūdas",
        "drebulys",
        "šokas",
        "menkas",
        "šaudyti",
        "Šaudymas",
        "parduotuvių parduotuvės",
        "trūkumas",
        "trūkumas",
        "kulka",
        "nuleisti",
        "šiltas",
        "šaukti",
        "siautėti",
        "susitraukti",
        "susitraukė",
        "drebulys",
        "apsisaugoti",
        "serga",
        "sielvartas",
        "blogas",
        "ligos",
        "kvailas",
        "NO TRANSLATION",
        "nuodėmingas",
        "žiaurus",
        "nusidėjėlis",
        "nusikaltimas",
        "sirena",
        "berniukas",
        "skeptiškas",
        "eskizas",
        "kaklusas",
        "slysti",
        "praleisti",
        "sustingimas",
        "laisvas",
        "šlakas",
        "slam",
        "šmeižtas",
        "šmeižikiškas",
        "slap",
        "skerdimas",
        "skerdykloje",
        "skerdimas",
        "vergas",
        "vergija",
        "sunaikinti",
        "Slayer",
        "sniegas",
        "blizgus",
        "nulenkti",
        "paslysti",
        "NO TRANSLATION",
        "nenuilstantis",
        "Liūdna",
        "slouch",
        "šluota",
        "lėtas",
        "dumblas",
        "šliužas",
        "vangus",
        "lūšna",
        "nuosmukis",
        "slysti",
        "skalauti",
        "liemenė",
        "kvailas",
        "šokti",
        "mažas",
        "sumušė",
        "sumušė",
        "smattering",
        "kvapas",
        "kvapas",
        "šnibžda",
        "smite",
        "rūkytojas",
        "nušluostyti",
        "pluta",
        "smagu",
        "kontrabanda",
        "kontrabandininkas",
        "kontrabanda",
        "smut",
        "užsikimšęs",
        "snags",
        "gyvatė",
        "spąstai",
        "snarl",
        "snarlingas",
        "sėlinti",
        "siautėti",
        "sneer",
        "Čiaudėti",
        "snide",
        "snobas",
        "mirkyti",
        "NO TRANSLATION",
        "socialistė",
        "dirvožemis",
        "užterštas",
        "somatinis",
        "siaubingas",
        "suodžiai",
        "burtininkas",
        "sordid",
        "skauda",
        "skausmingai",
        "skausmas",
        "liūdesys",
        "liūdnas",
        "NO TRANSLATION",
        "be jokios",
        "sielos draugas",
        "rūgštus",
        "spank",
        "spazmas",
        "švaistyti",
        "ietis",
        "speck",
        "spoksas",
        "Spektrinis",
        "spekuliacija",
        "išleista",
        "spinster",
        "nepaisant to",
        "piktas",
        "skalda",
        "padalinti",
        "padalijimas",
        "sugadinti",
        "spoileris",
        "kalbėjo",
        "kempinė",
        "spooky",
        "suspaudimas",
        "šypsotis",
        "sprite",
        "klaidingas",
        "škvalas",
        "Squatter",
        "gudrumas",
        "šlifuoti",
        "kramtyti",
        "stab",
        "stulbinantis",
        "sustingęs",
        "dėmė",
        "pasenusi",
        "kotelis",
        "atsilikimas",
        "sustabdyti",
        "žvilgsnis",
        "kietas",
        "sumušimas",
        "badas",
        "badaujantis",
        "badaujantis",
        "stacionarus",
        "tvirtovė",
        "pavogti",
        "vagystė",
        "slaptas",
        "stereotipas",
        "stereotipinis",
        "sterilus",
        "sterilumas",
        "sargas",
        "standus",
        "standumas",
        "užgniaužti",
        "slopinamas",
        "stigma",
        "negyvas",
        "girtis",
        "švelnus",
        "švelnus",
        "garsas",
        "liūdna",
        "tvirtumas",
        "atsargos",
        "pavogtas",
        "akmuo",
        "užmuštas akmenimis",
        "išmatos",
        "sustojimas",
        "audra",
        "audringas",
        "įtemptas",
        "sąsiauriai",
        "siaura",
        "svetimas",
        "pasislėpti",
        "bjaurus",
        "stresas",
        "nesantaika",
        "streikuoti",
        "juostelė",
        "juostelė",
        "išvalytas",
        "insultas",
        "kova",
        "statramstis",
        "uždaras",
        "pasipiktinti",
        "apsvaigintas",
        "stunted",
        "kvailas",
        "kvailys",
        "stuporas",
        "sty",
        "pavergti",
        "dalykas",
        "patyrė",
        "paklusnumas",
        "subjugavimas",
        "pavaldus",
        "teismo šaukimas",
        "nusileidimas",
        "subsidija",
        "išlikti",
        "atimti",
        "subversija",
        "griaunantis",
        "suplakti",
        "pasiduoti",
        "čiulpia",
        "siurblys",
        "iškelti bylą",
        "kenčia",
        "kančia",
        "kančios",
        "dusinanti",
        "dusulys",
        "savižudis",
        "savižudis",
        "nuobodus",
        "šaukimas",
        "nuskendo",
        "paviršutiniškas",
        "nereikalingas",
        "prietaringas",
        "slopinti",
        "slopinimas",
        "papildomas mokestis",
        "drąsus",
        "pasidavimas",
        "pasiduodamas",
        "jautrus",
        "įtariamasis",
        "sustabdymas",
        "įtarimas",
        "įtartinas",
        "tamponu",
        "pelkė",
        "pelkėtas",
        "Swastika",
        "patinimas",
        "swig",
        "kiaulės",
        "patinsta",
        "simptomas",
        "sinkopė",
        "tabu",
        "gaila",
        "NO TRANSLATION",
        "susipainioti",
        "tardiness",
        "tardy",
        "tarifas",
        "sumušti",
        "pasilikti",
        "beskonis",
        "juoktis",
        "mokestis",
        "erzinti",
        "erzinti",
        "nuobodus",
        "NO TRANSLATION",
        "audra",
        "pagunda",
        "nuoma",
        "terminalas",
        "nutraukimas",
        "termitas",
        "baisi",
        "teroras",
        "terorizmas",
        "teroristas",
        "terorizuoti",
        "stabligė",
        "juostos",
        "vagystė",
        "teizmas",
        "teokratiškas",
        "vagis",
        "ištroškęs",
        "erškėtis",
        "aštrus",
        "neapgalvotas",
        "Thrash",
        "grėsmė",
        "grasinti",
        "grasinanti",
        "šluostyti",
        "siaubas",
        "droselinė sklendė",
        "bjaurus",
        "sumušti",
        "griauniantis",
        "nulaužti",
        "tiff",
        "bjaurus",
        "bailumas",
        "tipy",
        "tirade",
        "pavargęs",
        "nuovargis",
        "varginantis",
        "šunys",
        "rupūžė",
        "tabakas",
        "tualetas",
        "rutuliai",
        "toleruoti",
        "dantų skausmas",
        "kankinimai",
        "suplyšusi",
        "torpedas",
        "saldus",
        "deliktas",
        "tariamai",
        "kankinimas",
        "palietė",
        "nešvarus",
        "kietas",
        "toksiškas",
        "toksinas",
        "tragedija",
        "tragiškas",
        "išdavikas",
        "trampinė",
        "trance",
        "nusikaltimas",
        "apkaustai",
        "spąstai",
        "šiukšlių dėžė",
        "netinkamas",
        "trauminis",
        "NO TRANSLATION",
        "travesty",
        "klastingas",
        "išdavystė",
        "išdavystė",
        "drebulys",
        "drebulys",
        "trepidas",
        "nusižengimas",
        "bėdas",
        "tribunolas",
        "triukas",
        "apgaulė",
        "smulkmena",
        "atsikratyti",
        "Trollas",
        "varginantis",
        "trimitas",
        "sunaikinti",
        "navikas",
        "navikas",
        "triukšmas",
        "audringas",
        "turbulencija",
        "neramumas",
        "neramumai",
        "trauktis",
        "taifūnas",
        "tironiškas",
        "tironija",
        "tyrantas",
        "bjaurumas",
        "negraži",
        "opa",
        "laukia",
        "ultimatumas",
        "negali",
        "nepriimtina",
        "neatsakomas",
        "nepatvirtinta",
        "neprijungtas",
        "nepasiekiamas",
        "nepatrauklus",
        "neleistinas",
        "neišvengiamas",
        "nežino",
        "nepakeliamas",
        "netikėjimas",
        "neįtikėtinas",
        "negimusi",
        "nepatogus",
        "neprilygstamas",
        "neaišku",
        "nepakeičiama",
        "nešvarus",
        "nepatogus",
        "nepagrįstas",
        "nesąmoningas",
        "nekonstitucinis",
        "nekontroliuojamas",
        "nekontroliuojamas",
        "neapsisprendęs",
        "pažeistas",
        "nepakankamai mokama",
        "mažai",
        "nepageidautinas",
        "nepageidautinas",
        "anuliuoti",
        "neramumas",
        "neramus",
        "nebaigtas",
        "bedarbiai",
        "nevienodas",
        "nevienodas",
        "nepaaiškinamas",
        "Nesąžininga",
        "nesąžiningumas",
        "netikri",
        "nepalankus",
        "nebaigtas",
        "nepagarbus",
        "nevykęs",
        "nedraugiškas",
        "neįvykdyta",
        "be miegamojo",
        "bedievis",
        "nepagarbus",
        "nelaimė",
        "nelaimingas",
        "nesveika",
        "nepagrįstas",
        "nesvarbus",
        "nesužavėtas",
        "nepagerintas",
        "neinformuotas",
        "nedvarbu",
        "neinspired",
        "nesuprantamas",
        "netyčia",
        "nesvarbu",
        "neįdomu",
        "neteisingas",
        "nepagrįstas",
        "nepagrįstas",
        "negeras",
        "nežinomas",
        "neteisėtas",
        "nelicencijuota",
        "nelaimingas",
        "nevaldomas",
        "nenatūralus",
        "neoficialus",
        "nemokama",
        "nemalonus",
        "nepopuliarus",
        "nenuspėjamas",
        "nepasiruošęs",
        "neproduktyvus",
        "nepelningas",
        "neapsaugotas",
        "nepaskelbtas",
        "nepatikimas",
        "nepatenkintas",
        "nepaklusnus",
        "nesaugu",
        "nepatenkinama",
        "nepatenkintas",
        "nepatogu",
        "nesąžiningi",
        "nesuderinta",
        "nesvarbu",
        "nesudėtingas",
        "neapsakomas",
        "nestabilus",
        "nesėkmingas",
        "netinkamas",
        "nepaskelbta",
        "nepatvirtintas",
        "netvarus",
        "nesimpatėjantis",
        "nepagrįstas",
        "nepagrįstas",
        "neįsivaizduojamas",
        "netinkamas",
        "per anksti",
        "untitled",
        "neapsakomas",
        "nepageidaujamas",
        "nepatyrusi",
        "neteisinga",
        "nepatikimas",
        "nepagrįstas",
        "neplautas",
        "nepageidautinas",
        "blogai",
        "nenoras",
        "neprotingas",
        "netikras",
        "nepagrįstas",
        "neprilygstamas",
        "perversmas",
        "sukilimas",
        "šurmulys",
        "liūdnas",
        "urchin",
        "skubiai",
        "nenaudingas",
        "usurp",
        "usurped",
        "likutis",
        "laisva vieta",
        "laisvas",
        "neaiškus",
        "neapibrėžtumas",
        "veltui",
        "vampyras",
        "praėjo",
        "tuštybė",
        "vėjaraupiai",
        "varikozė",
        "vegetatyvinis",
        "kupinas",
        "vendetta",
        "kerštas",
        "kerštingas",
        "nuodai",
        "nuodingas",
        "verbavimas",
        "riba",
        "kenkėjai",
        "prieš",
        "vertigo",
        "veto",
        "viceprezidentas",
        "piktas",
        "auka",
        "nukentėjęs",
        "piktadarys",
        "piktasis",
        "kaltinamasis",
        "pažeidimas",
        "smurtas",
        "smurtinis",
        "smarkiai",
        "viper",
        "virulentiškumas",
        "virusas",
        "apsilankymas",
        "vixen",
        "kintamumas",
        "vulkanas",
        "vėmimas",
        "voodoo",
        "vulgarus",
        "vulgarumas",
        "pažeidžiamumas",
        "grifas",
        "vaflis",
        "Wielać",
        "laukti",
        "nuleisti",
        "NO TRANSLATION",
        "nuslopinti",
        "nori",
        "karas",
        "globėjas",
        "gaminiai",
        "karas",
        "kareiviškas",
        "perspėk",
        "metmenis",
        "deformuoti",
        "karpis",
        "atliekos",
        "švaistomi",
        "švaistomi",
        "švaistyti",
        "vandeningas",
        "pabusti",
        "susilpnėjęs",
        "silpnai",
        "silpnumas",
        "dėvėti",
        "nuobodžiai",
        "nuovargis",
        "nuobodus",
        "piktžoles",
        "verkia",
        "keista",
        "weirdo",
        "NO TRANSLATION",
        "žvilgsnis",
        "sumušti",
        "kaprizas",
        "šypsotis",
        "plakti",
        "sūkurys",
        "viskis",
        "kekše",
        "nelaimingas",
        "nedorybė",
        "laukinis",
        "Wildcat",
        "Laukinė ugnis",
        "tyčinis",
        "wimp",
        "wimpy",
        "nuraminti",
        "ragana",
        "raganavimas",
        "pasitraukti",
        "nurimo",
        "nudrus",
        "Vargas",
        "bjaurus",
        "apgailestauju",
        "žodžiai",
        "kirminas",
        "dėvėti",
        "neramus",
        "nerimauti",
        "nerimas",
        "blogiau",
        "blogėja",
        "beverčiai",
        "žaizdos",
        "ginčytis",
        "rūstybė",
        "sumušti",
        "avarija",
        "sudaužytas",
        "veržliaraktis",
        "imtynės",
        "nelaimingas",
        "apgailėtinas",
        "neteisingai",
        "piktnaudžiavimas",
        "neteisėtas",
        "klaidingai",
        "padaryta",
        "wry",
        "ksenofobija",
        "žiovulys",
        "žiovavimas",
        "klaida",
        "geltonos spalvos",
        "juoktis",
        "zip",
    ]
)

_ambivalent = set(
    [
        "gausa",
        "ginkluotosios",
        "balzamas",
        "pasigirti",
        "audringas",
        "knygynas",
        "Buck",
        "garsenybė",
        "susižavėjo",
        "vengimas",
        "komplikacija",
        "prisipažinti",
        "gudrus",
        "priklausomas",
        "įvairus",
        "dominuoti",
        "begalinis",
        "vykdomas",
        "erotika",
        "Pabegti",
        "jausmas",
        "flirtuoti",
        "kruša",
        "hedonizmas",
        "aukščiausias",
        "kuklus",
        "nedelsiant",
        "nekilnojamasis",
        "pajamos",
        "infiltracija",
        "įtaka",
        "intensyvus",
        "be galo",
        "intervencija",
        "nėriniai",
        "liberalus",
        "Viešpatie",
        "motina",
        "akušerė",
        "motina",
        "puodelis",
        "žinomumas",
        "visagalis",
        "sprogimas",
        "išskirtinis",
        "paradas",
        "parafrazuoti",
        "naftos",
        "pateikimas",
        "bjaurus",
        "citata",
        "rave",
        "regresyvus",
        "atgaivinti",
        "lieka",
        "pensija",
        "atgimti",
        "revoliucija",
        "Kaliausė",
        "atskirtis",
        "jausmingas",
        "aklas",
        "stuburo dalis",
        "sterlingas",
        "sultingas",
        "prietarai",
        "viršenybė",
        "apsupti",
        "sinonimas",
        "tantalizing",
        "paaugliai",
        "gydyk",
        "nepralaimėta",
        "nevaldomas",
        "netikėtas",
        "neįsivaizduojamas",
        "atsitraukite",
        "į kalną",
        "balsas",
        "svoris",
        "ilgesys",
    ]
)



"""
@author: alfonso.semeraro@unito.it

"""

import numpy as np
import itertools
import emoatlas.textloader as _txl
from random import choices


def _get_emotions(
    obj,
    emotion_lexicon,
    language,
    normalization_strategy,
    tagger,
    emotions,
    return_words,
    emojis_dict,
    convert_emojis,
    idiomatic_tokens,
):

    wordlist = _txl._load_object(
        obj=obj,
        language=language,
        tagger=tagger,
        emojis_dict=emojis_dict,
        convert_emojis=convert_emojis,
        idiomatic_tokens=idiomatic_tokens,
    )

    # word-emotion pairs
    emowords = [
        [(w, emo) for emo in emotion_lexicon[w]]
        for w in wordlist
        if w in emotion_lexicon
    ]
    emowords = list(itertools.chain(*emowords))

    # emotion: count, list of words
    emowords = {
        emo: list(set([word for word, emotion in emowords if emo == emotion]))
        for emo in emotions
    }
    emowords = {
        emo: {"count": len(emo_words), "words": emo_words}
        for emo, emo_words in emowords.items()
    }

    if return_words:

        if language != "english":
            reverse_id_tok = {val: key for key, val in idiomatic_tokens.items()}
            for emo in emowords:
                emowords[emo]["words"] = [
                    reverse_id_tok[w] if w in reverse_id_tok else w
                    for w in emowords[emo]["words"]
                ]
        return emowords

    else:
        emowords = {emo: emowords[emo]["count"] for emo in emowords}

        if normalization_strategy == "text_length":
            N = len(wordlist)
            emowords = {key: val / N if N else 0 for key, val in emowords.items()}

        elif normalization_strategy == "emotion_words":
            N = sum(emowords.values())
            emowords = {key: val / N if N else 0 for key, val in emowords.items()}

    return emowords


def _zscores(
    obj,
    baseline,
    n_samples,
    emotion_lexicon,
    language,
    tagger,
    emotions,
    lookup,
    emojis_dict,
    convert_emojis,
    idiomatic_tokens,
):

    emotion_words = _get_emotions(
        obj=obj,
        emotion_lexicon=emotion_lexicon,
        language=language,
        normalization_strategy="none",
        tagger=tagger,
        emotions=emotions,
        return_words=True,
        emojis_dict=emojis_dict,
        convert_emojis=convert_emojis,
        idiomatic_tokens=idiomatic_tokens,
    )

    # # text_emo: 'joy': 'L'
    # S = sum([emotion_words[emo]['count'] for emo in emotions])
    # text_emo = {emo: emotion_words[emo]['count']/S if S != 0 else 0 for emo in emotions}

    # N words to sample
    N = len(set(itertools.chain(*[emotion_words[emo]["words"] for emo in emotions])))

    # No 1 word sentences
    if N == 1:
        return {
            emo: 2 if emotion_words[emo]["count"] > 0 else 0 for emo in emotion_words
        }

    # Few emotion words? only count emotions that appear twice
    elif N <= 5:
        return {
            emo: 2 if emotion_words[emo]["count"] > 1 else 0 for emo in emotion_words
        }

    # N is in the lookup table
    if N in lookup:
        zscores = {
            emo: (
                (emotion_words[emo].get("count", 0) - lookup[N][emo]["mean"])
                / lookup[N][emo]["std"]
                if lookup[N][emo]["std"]
                else 0
            )
            for emo in emotions
        }
        return zscores

    # otherwise I'll compute it and add it to lookup

    # all samples together
    all_samples = {emo: [] for emo in emotions}

    for _ in range(n_samples):

        # random choice N with prob
        sample = choices(baseline[0], weights=baseline[1], k=N)
        sample = list(itertools.chain(*sample))

        # count emotions
        sample = {emo: sample.count(emo) for emo in emotions}

        # add to all_samples
        all_samples = {emo: all_samples[emo] + [sample.get(emo, 0)] for emo in emotions}

    # All samples: 'joy': 'mean': ... 'std': ...
    # Add all samples to lookup[N]
    all_samples = {
        emo: {"mean": np.mean(all_samples[emo]), "std": np.std(all_samples[emo])}
        for emo in emotions
    }
    lookup[N] = all_samples

    # Get z-scores
    zscores = {
        emo: (
            (emotion_words[emo].get("count", 0) - all_samples[emo]["mean"])
            / all_samples[emo]["std"]
            if all_samples[emo]["std"]
            else 0
        )
        for emo in emotions
    }

    return zscores
